Option Explicit On
Option Strict On

Imports System.Runtime.InteropServices

Public Module Cv
	'/*M///////////////////////////////////////////////////////////////////////////////////////
	'//
	'//  IMPORTANT: READ BEFORE DOWNLOADING, COPYING, INSTALLING OR USING.
	'//
	'//  By downloading, copying, installing or using the software you agree to this license.
	'//  If you do not agree to this license, do not download, install,
	'//  copy or use the software.
	'//
	'//
	'//                        Intel License Agreement
	'//                For Open Source Computer Vision Library
	'//
	'// Copyright (C) 2000, Intel Corporation, all rights reserved.
	'// Third party copyrights are property of their respective owners.
	'//
	'// Redistribution and use in source and binary forms, with or without modification,
	'// are permitted provided that the following conditions are met:
	'//
	'//   * Redistribution's of source code must retain the above copyright notice,
	'//     this list of conditions and the following disclaimer.
	'//
	'//   * Redistribution's in binary form must reproduce the above copyright notice,
	'//     this list of conditions and the following disclaimer in the documentation
	'//     and/or other materials provided with the distribution.
	'//
	'//   * The name of Intel Corporation may not be used to endorse or promote products
	'//     derived from this software without specific prior written permission.
	'//
	'// This software is provided by the copyright holders and contributors "as is" and
	'// any express or implied warranties, including, but not limited to, the implied
	'// warranties of merchantability and fitness for a particular purpose are disclaimed.
	'// In no event shall the Intel Corporation or contributors be liable for any direct,
	'// indirect, incidental, special, exemplary, or consequential damages
	'// (including, but not limited to, procurement of substitute goods or services;
	'// loss of use, data, or profits; or business interruption) however caused
	'// and on any theory of liability, whether in contract, strict liability,
	'// or tort (including negligence or otherwise) arising in any way out of
	'// the use of this software, even if advised of the possibility of such damage.
	'//
	'//M*/


	'/****************************************************************************************\
	'*                                    Image Processing                                    *
	'\****************************************************************************************/

	'/* Copies source 2D array inside of the larger destination array and
	'   makes a border of the specified type (IPL_BORDER_*) around the copied area. */
	'CVAPI(void) cvCopyMakeBorder( const CvArr* src, CvArr* dst, CvPoint offset,
	'                              int bordertype, CvScalar value CV_DEFAULT(cvScalarAll(0)));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCopyMakeBorder(byval src as intptr,byval dst as intptr,byval offset as CvPoint,byval bordertype as integer,byval value as CvScalar)
	end sub

	'#define CV_BLUR_NO_SCALE 0
	public const  CV_BLUR_NO_SCALE as integer =  0
	'#define CV_BLUR  1
	public const  CV_BLUR as integer =  1
	'#define CV_GAUSSIAN  2
	public const  CV_GAUSSIAN as integer =  2
	'#define CV_MEDIAN 3
	public const  CV_MEDIAN as integer =  3
	'#define CV_BILATERAL 4
	public const  CV_BILATERAL as integer =  4

	'/* Smoothes array (removes noise) */
	'CVAPI(void) cvSmooth( const CvArr* src, CvArr* dst,
	'                      int smoothtype CV_DEFAULT(CV_GAUSSIAN),
	'                      int param1 CV_DEFAULT(3),
	'                      int param2 CV_DEFAULT(0),
	'                      double param3 CV_DEFAULT(0),
	'                      double param4 CV_DEFAULT(0));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSmooth(byval src as intptr,byval dst as intptr,byval smoothtype as integer,byval param1 as integer,byval param2 as integer,byval param3 as double,byval param4 as double)
	end sub

	'/* Convolves the image with the kernel */
	'CVAPI(void) cvFilter2D( const CvArr* src, CvArr* dst, const CvMat* kernel,
	'                        CvPoint anchor CV_DEFAULT(cvPoint(-1,-1)));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFilter2D(byval src as intptr,byval dst as intptr,byref kernel as CvMat,byval anchor as CvPoint)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFilter2D(byval src as intptr,byval dst as intptr,byval kernel as intptr,byval anchor as CvPoint)
	end sub

	'/* Finds integral image: SUM(X,Y) = sum(x<X,y<Y)I(x,y) */
	'CVAPI(void) cvIntegral( const CvArr* image, CvArr* sum,
	'                       CvArr* sqsum CV_DEFAULT(NULL),
	'                       CvArr* tilted_sum CV_DEFAULT(NULL));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvIntegral(byval image as intptr,byval sum as intptr,byval sqsum as intptr,byval tilted_sum as intptr)
	end sub

	'/*
	'   Smoothes the input image with gaussian kernel and then down-samples it.
	'   dst_width = floor(src_width/2)[+1],
	'   dst_height = floor(src_height/2)[+1]
	'*/
	'CVAPI(void)  cvPyrDown( const CvArr* src, CvArr* dst,
	'                        int filter CV_DEFAULT(CV_GAUSSIAN_5x5) );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvPyrDown(byval src as intptr,byval dst as intptr,byval filter as integer)
	end sub

	'/* 
	'   Up-samples image and smoothes the result with gaussian kernel.
	'   dst_width = src_width*2,
	'   dst_height = src_height*2
	'*/
	'CVAPI(void)  cvPyrUp( const CvArr* src, CvArr* dst,
	'                      int filter CV_DEFAULT(CV_GAUSSIAN_5x5) );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvPyrUp(byval src as intptr,byval dst as intptr,byval filter as integer)
	end sub


	'/* Builds the whole pyramid at once. Output array of CvMat headers (levels[*])
	'   is initialized with the headers of subsequent pyramid levels */
	'/*CVAPI  void  cvCalcPyramid( const CvArr* src, CvArr* container,
	'                              CvMat* levels, int level_count,
	'                              int filter CV_DEFAULT(CV_GAUSSIAN_5x5) );*/


	'/* Splits color or grayscale image into multiple connected components
	'   of nearly the same color/brightness using modification of Burt algorithm.
	'   comp with contain a pointer to sequence (CvSeq)
	'   of connected components (CvConnectedComp) */
	'CVAPI(void) cvPyrSegmentation( IplImage* src, IplImage* dst,
	'                              CvMemStorage* storage, CvSeq** comp,
	'                              int level, double threshold1,
	'                              double threshold2 );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvPyrSegmentation(byref src as IplImage,byref dst as IplImage,byref storage as CvMemStorage,ByRef comp As intptr,byval level as integer,byval threshold1 as double,byval threshold2 as double)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvPyrSegmentation(byval src as intptr,byref dst as IplImage,byref storage as CvMemStorage,ByRef comp As intptr,byval level as integer,byval threshold1 as double,byval threshold2 as double)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvPyrSegmentation(byref src as IplImage,byval dst as intptr,byref storage as CvMemStorage,ByRef comp As intptr,byval level as integer,byval threshold1 as double,byval threshold2 as double)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvPyrSegmentation(byval src as intptr,byval dst as intptr,byref storage as CvMemStorage,ByRef comp As intptr,byval level as integer,byval threshold1 as double,byval threshold2 as double)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvPyrSegmentation(byref src as IplImage,byref dst as IplImage,byval storage as intptr,ByRef comp As intptr,byval level as integer,byval threshold1 as double,byval threshold2 as double)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvPyrSegmentation(byval src as intptr,byref dst as IplImage,byval storage as intptr,ByRef comp As intptr,byval level as integer,byval threshold1 as double,byval threshold2 as double)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvPyrSegmentation(byref src as IplImage,byval dst as intptr,byval storage as intptr,ByRef comp As intptr,byval level as integer,byval threshold1 as double,byval threshold2 as double)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvPyrSegmentation(byval src as intptr,byval dst as intptr,byval storage as intptr,ByRef comp As intptr,byval level as integer,byval threshold1 as double,byval threshold2 as double)
	end sub

	'/* Filters image using meanshift algorithm */
	'CVAPI(void) cvPyrMeanShiftFiltering( const CvArr* src, CvArr* dst, 
	'    double sp, double sr, int max_level CV_DEFAULT(1),
	'    CvTermCriteria termcrit CV_DEFAULT(cvTermCriteria(CV_TERMCRIT_ITER+CV_TERMCRIT_EPS,5,1)));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvPyrMeanShiftFiltering(byval src as intptr,byval dst as intptr,byval sp as double,byval sr as double,byval max_level as integer,byval termcrit as CvTermCriteria)
	end sub

	'/* Segments image using seed "markers" */
	'CVAPI(void) cvWatershed( const CvArr* image, CvArr* markers );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvWatershed(byval image as intptr,byval markers as intptr)
	end sub

	'#define CV_INPAINT_NS      0
	public const  CV_INPAINT_NS as integer =  0
	'#define CV_INPAINT_TELEA   1
	public const  CV_INPAINT_TELEA as integer =  1

	'/* Inpaints the selected region in the image */
	'CVAPI(void) cvInpaint( const CvArr* src, const CvArr* inpaint_mask,
	'                       CvArr* dst, double inpaintRange, int flags );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvInpaint(byval src as intptr,byval inpaint_mask as intptr,byval dst as intptr,byval inpaintRange as double,byval flags as integer)
	end sub

	'#define CV_SCHARR -1
	public const  CV_SCHARR as integer =  -1
	'#define CV_MAX_SOBEL_KSIZE 7
	public const  CV_MAX_SOBEL_KSIZE as integer =  7

	'/* Calculates an image derivative using generalized Sobel
	'   (aperture_size = 1,3,5,7) or Scharr (aperture_size = -1) operator.
	'   Scharr can be used only for the first dx or dy derivative */
	'CVAPI(void) cvSobel( const CvArr* src, CvArr* dst,
	'                    int xorder, int yorder,
	'                    int aperture_size CV_DEFAULT(3));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSobel(byval src as intptr,byval dst as intptr,byval xorder as integer,byval yorder as integer,byval aperture_size as integer)
	end sub

	'/* Calculates the image Laplacian: (d2/dx + d2/dy)I */
	'CVAPI(void) cvLaplace( const CvArr* src, CvArr* dst,
	'                      int aperture_size CV_DEFAULT(3) );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvLaplace(byval src as intptr,byval dst as intptr,byval aperture_size as integer)
	end sub

	'/* Constants for color conversion */
	'#define  CV_BGR2BGRA    0
	public const  CV_BGR2BGRA as integer =  0
	'#define  CV_RGB2RGBA    CV_BGR2BGRA
	public const  CV_RGB2RGBA as integer =  CV_BGR2BGRA

	'#define  CV_BGRA2BGR    1
	public const  CV_BGRA2BGR as integer =  1
	'#define  CV_RGBA2RGB    CV_BGRA2BGR
	public const  CV_RGBA2RGB as integer =  CV_BGRA2BGR

	'#define  CV_BGR2RGBA    2
	public const  CV_BGR2RGBA as integer =  2
	'#define  CV_RGB2BGRA    CV_BGR2RGBA
	public const  CV_RGB2BGRA as integer =  CV_BGR2RGBA

	'#define  CV_RGBA2BGR    3
	public const  CV_RGBA2BGR as integer =  3
	'#define  CV_BGRA2RGB    CV_RGBA2BGR
	public const  CV_BGRA2RGB as integer =  CV_RGBA2BGR

	'#define  CV_BGR2RGB     4
	public const  CV_BGR2RGB as integer =  4
	'#define  CV_RGB2BGR     CV_BGR2RGB
	public const  CV_RGB2BGR as integer =  CV_BGR2RGB

	'#define  CV_BGRA2RGBA   5
	public const  CV_BGRA2RGBA as integer =  5
	'#define  CV_RGBA2BGRA   CV_BGRA2RGBA
	public const  CV_RGBA2BGRA as integer =  CV_BGRA2RGBA

	'#define  CV_BGR2GRAY    6
	public const  CV_BGR2GRAY as integer =  6
	'#define  CV_RGB2GRAY    7
	public const  CV_RGB2GRAY as integer =  7
	'#define  CV_GRAY2BGR    8
	public const  CV_GRAY2BGR as integer =  8
	'#define  CV_GRAY2RGB    CV_GRAY2BGR
	public const  CV_GRAY2RGB as integer =  CV_GRAY2BGR
	'#define  CV_GRAY2BGRA   9
	public const  CV_GRAY2BGRA as integer =  9
	'#define  CV_GRAY2RGBA   CV_GRAY2BGRA
	public const  CV_GRAY2RGBA as integer =  CV_GRAY2BGRA
	'#define  CV_BGRA2GRAY   10
	public const  CV_BGRA2GRAY as integer =  10
	'#define  CV_RGBA2GRAY   11
	public const  CV_RGBA2GRAY as integer =  11

	'#define  CV_BGR2BGR565  12
	public const  CV_BGR2BGR565 as integer =  12
	'#define  CV_RGB2BGR565  13
	public const  CV_RGB2BGR565 as integer =  13
	'#define  CV_BGR5652BGR  14
	public const  CV_BGR5652BGR as integer =  14
	'#define  CV_BGR5652RGB  15
	public const  CV_BGR5652RGB as integer =  15
	'#define  CV_BGRA2BGR565 16
	public const  CV_BGRA2BGR565 as integer =  16
	'#define  CV_RGBA2BGR565 17
	public const  CV_RGBA2BGR565 as integer =  17
	'#define  CV_BGR5652BGRA 18
	public const  CV_BGR5652BGRA as integer =  18
	'#define  CV_BGR5652RGBA 19
	public const  CV_BGR5652RGBA as integer =  19

	'#define  CV_GRAY2BGR565 20
	public const  CV_GRAY2BGR565 as integer =  20
	'#define  CV_BGR5652GRAY 21
	public const  CV_BGR5652GRAY as integer =  21

	'#define  CV_BGR2BGR555  22
	public const  CV_BGR2BGR555 as integer =  22
	'#define  CV_RGB2BGR555  23
	public const  CV_RGB2BGR555 as integer =  23
	'#define  CV_BGR5552BGR  24
	public const  CV_BGR5552BGR as integer =  24
	'#define  CV_BGR5552RGB  25
	public const  CV_BGR5552RGB as integer =  25
	'#define  CV_BGRA2BGR555 26
	public const  CV_BGRA2BGR555 as integer =  26
	'#define  CV_RGBA2BGR555 27
	public const  CV_RGBA2BGR555 as integer =  27
	'#define  CV_BGR5552BGRA 28
	public const  CV_BGR5552BGRA as integer =  28
	'#define  CV_BGR5552RGBA 29
	public const  CV_BGR5552RGBA as integer =  29

	'#define  CV_GRAY2BGR555 30
	public const  CV_GRAY2BGR555 as integer =  30
	'#define  CV_BGR5552GRAY 31
	public const  CV_BGR5552GRAY as integer =  31

	'#define  CV_BGR2XYZ     32
	public const  CV_BGR2XYZ as integer =  32
	'#define  CV_RGB2XYZ     33
	public const  CV_RGB2XYZ as integer =  33
	'#define  CV_XYZ2BGR     34
	public const  CV_XYZ2BGR as integer =  34
	'#define  CV_XYZ2RGB     35
	public const  CV_XYZ2RGB as integer =  35

	'#define  CV_BGR2YCrCb   36
	public const  CV_BGR2YCrCb as integer =  36
	'#define  CV_RGB2YCrCb   37
	public const  CV_RGB2YCrCb as integer =  37
	'#define  CV_YCrCb2BGR   38
	public const  CV_YCrCb2BGR as integer =  38
	'#define  CV_YCrCb2RGB   39
	public const  CV_YCrCb2RGB as integer =  39

	'#define  CV_BGR2HSV     40
	public const  CV_BGR2HSV as integer =  40
	'#define  CV_RGB2HSV     41
	public const  CV_RGB2HSV as integer =  41

	'#define  CV_BGR2Lab     44
	public const  CV_BGR2Lab as integer =  44
	'#define  CV_RGB2Lab     45
	public const  CV_RGB2Lab as integer =  45

	'#define  CV_BayerBG2BGR 46
	public const  CV_BayerBG2BGR as integer =  46
	'#define  CV_BayerGB2BGR 47
	public const  CV_BayerGB2BGR as integer =  47
	'#define  CV_BayerRG2BGR 48
	public const  CV_BayerRG2BGR as integer =  48
	'#define  CV_BayerGR2BGR 49
	public const  CV_BayerGR2BGR as integer =  49

	'#define  CV_BayerBG2RGB CV_BayerRG2BGR
	public const  CV_BayerBG2RGB as integer =  CV_BayerRG2BGR
	'#define  CV_BayerGB2RGB CV_BayerGR2BGR
	public const  CV_BayerGB2RGB as integer =  CV_BayerGR2BGR
	'#define  CV_BayerRG2RGB CV_BayerBG2BGR
	public const  CV_BayerRG2RGB as integer =  CV_BayerBG2BGR
	'#define  CV_BayerGR2RGB CV_BayerGB2BGR
	public const  CV_BayerGR2RGB as integer =  CV_BayerGB2BGR

	'#define  CV_BGR2Luv     50
	public const  CV_BGR2Luv as integer =  50
	'#define  CV_RGB2Luv     51
	public const  CV_RGB2Luv as integer =  51
	'#define  CV_BGR2HLS     52
	public const  CV_BGR2HLS as integer =  52
	'#define  CV_RGB2HLS     53
	public const  CV_RGB2HLS as integer =  53

	'#define  CV_HSV2BGR     54
	public const  CV_HSV2BGR as integer =  54
	'#define  CV_HSV2RGB     55
	public const  CV_HSV2RGB as integer =  55

	'#define  CV_Lab2BGR     56
	public const  CV_Lab2BGR as integer =  56
	'#define  CV_Lab2RGB     57
	public const  CV_Lab2RGB as integer =  57
	'#define  CV_Luv2BGR     58
	public const  CV_Luv2BGR as integer =  58
	'#define  CV_Luv2RGB     59
	public const  CV_Luv2RGB as integer =  59
	'#define  CV_HLS2BGR     60
	public const  CV_HLS2BGR as integer =  60
	'#define  CV_HLS2RGB     61
	public const  CV_HLS2RGB as integer =  61

	'#define  CV_COLORCVT_MAX  100
	public const  CV_COLORCVT_MAX as integer =  100

	'/* Converts input array pixels from one color space to another */
	'CVAPI(void)  cvCvtColor( const CvArr* src, CvArr* dst, int code );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCvtColor(byval src as intptr,byval dst as intptr,byval code as integer)
	end sub

	'#define  CV_INTER_NN        0
	public const  CV_INTER_NN as integer =  0
	'#define  CV_INTER_LINEAR    1
	public const  CV_INTER_LINEAR as integer =  1
	'#define  CV_INTER_CUBIC     2
	public const  CV_INTER_CUBIC as integer =  2
	'#define  CV_INTER_AREA      3
	public const  CV_INTER_AREA as integer =  3

	'#define  CV_WARP_FILL_OUTLIERS 8
	public const  CV_WARP_FILL_OUTLIERS as integer =  8
	'#define  CV_WARP_INVERSE_MAP  16
	public const  CV_WARP_INVERSE_MAP as integer =  16

	'/* Resizes image (input array is resized to fit the destination array) */
	'CVAPI(void)  cvResize( const CvArr* src, CvArr* dst,
	'                       int interpolation CV_DEFAULT( CV_INTER_LINEAR ));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvResize(byval src as intptr,byval dst as intptr,byval interpolation as integer)
	end sub

	'/* Warps image with affine transform */ 
	'CVAPI(void)  cvWarpAffine( const CvArr* src, CvArr* dst, const CvMat* map_matrix,
	'                           int flags CV_DEFAULT(CV_INTER_LINEAR+CV_WARP_FILL_OUTLIERS),
	'                           CvScalar fillval CV_DEFAULT(cvScalarAll(0)) );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvWarpAffine(byval src as intptr,byval dst as intptr,byref map_matrix as CvMat,byval flags as integer,byval fillval as CvScalar)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvWarpAffine(byval src as intptr,byval dst as intptr,byval map_matrix as intptr,byval flags as integer,byval fillval as CvScalar)
	end sub

	'/* Computes affine transform matrix for mapping src[i] to dst[i] (i=0,1,2) */
	'CVAPI(CvMat*) cvGetAffineTransform( const CvPoint2D32f * src, 
	'                                    const CvPoint2D32f * dst, 
	'                                    CvMat * map_matrix );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvGetAffineTransform(byref src as CvPoint2D32f,byref dst as CvPoint2D32f,byref map_matrix as CvMat) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvGetAffineTransform(byval src as intptr,byref dst as CvPoint2D32f,byref map_matrix as CvMat) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvGetAffineTransform(byref src as CvPoint2D32f,byval dst as intptr,byref map_matrix as CvMat) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvGetAffineTransform(byval src as intptr,byval dst as intptr,byref map_matrix as CvMat) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvGetAffineTransform(byref src as CvPoint2D32f,byref dst as CvPoint2D32f,byval map_matrix as intptr) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvGetAffineTransform(byval src as intptr,byref dst as CvPoint2D32f,byval map_matrix as intptr) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvGetAffineTransform(byref src as CvPoint2D32f,byval dst as intptr,byval map_matrix as intptr) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvGetAffineTransform(byval src as intptr,byval dst as intptr,byval map_matrix as intptr) as IntPtr
	end function

	'/* Computes rotation_matrix matrix */
	'CVAPI(CvMat*)  cv2DRotationMatrix( CvPoint2D32f center, double angle,
	'                                   double scale, CvMat* map_matrix );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cv2DRotationMatrix(byval center as CvPoint2D32f,byval angle as double,byval scale as double,byref map_matrix as CvMat) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cv2DRotationMatrix(byval center as CvPoint2D32f,byval angle as double,byval scale as double,byval map_matrix as intptr) as IntPtr
	end function

	'/* Warps image with perspective (projective) transform */
	'CVAPI(void)  cvWarpPerspective( const CvArr* src, CvArr* dst, const CvMat* map_matrix,
	'                                int flags CV_DEFAULT(CV_INTER_LINEAR+CV_WARP_FILL_OUTLIERS),
	'                                CvScalar fillval CV_DEFAULT(cvScalarAll(0)) );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvWarpPerspective(byval src as intptr,byval dst as intptr,byref map_matrix as CvMat,byval flags as integer,byval fillval as CvScalar)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvWarpPerspective(byval src as intptr,byval dst as intptr,byval map_matrix as intptr,byval flags as integer,byval fillval as CvScalar)
	end sub

	'/* Computes perspective transform matrix for mapping src[i] to dst[i] (i=0,1,2,3) */
	'CVAPI(CvMat*) cvGetPerspectiveTransform( const CvPoint2D32f* src,
	'                                         const CvPoint2D32f* dst,
	'                                         CvMat* map_matrix );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvGetPerspectiveTransform(byref src as CvPoint2D32f,byref dst as CvPoint2D32f,byref map_matrix as CvMat) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvGetPerspectiveTransform(byval src as intptr,byref dst as CvPoint2D32f,byref map_matrix as CvMat) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvGetPerspectiveTransform(byref src as CvPoint2D32f,byval dst as intptr,byref map_matrix as CvMat) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvGetPerspectiveTransform(byval src as intptr,byval dst as intptr,byref map_matrix as CvMat) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvGetPerspectiveTransform(byref src as CvPoint2D32f,byref dst as CvPoint2D32f,byval map_matrix as intptr) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvGetPerspectiveTransform(byval src as intptr,byref dst as CvPoint2D32f,byval map_matrix as intptr) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvGetPerspectiveTransform(byref src as CvPoint2D32f,byval dst as intptr,byval map_matrix as intptr) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvGetPerspectiveTransform(byval src as intptr,byval dst as intptr,byval map_matrix as intptr) as IntPtr
	end function

	'/* Performs generic geometric transformation using the specified coordinate maps */
	'CVAPI(void)  cvRemap( const CvArr* src, CvArr* dst,
	'                      const CvArr* mapx, const CvArr* mapy,
	'                      int flags CV_DEFAULT(CV_INTER_LINEAR+CV_WARP_FILL_OUTLIERS),
	'                      CvScalar fillval CV_DEFAULT(cvScalarAll(0)) );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvRemap(byval src as intptr,byval dst as intptr,byval mapx as intptr,byval mapy as intptr,byval flags as integer,byval fillval as CvScalar)
	end sub

	'/* Performs forward or inverse log-polar image transform */
	'CVAPI(void)  cvLogPolar( const CvArr* src, CvArr* dst,
	'                         CvPoint2D32f center, double M,
	'                         int flags CV_DEFAULT(CV_INTER_LINEAR+CV_WARP_FILL_OUTLIERS));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvLogPolar(byval src as intptr,byval dst as intptr,byval center as CvPoint2D32f,byval M as double,byval flags as integer)
	end sub

	'#define  CV_SHAPE_RECT      0
	public const  CV_SHAPE_RECT as integer =  0
	'#define  CV_SHAPE_CROSS     1
	public const  CV_SHAPE_CROSS as integer =  1
	'#define  CV_SHAPE_ELLIPSE   2
	public const  CV_SHAPE_ELLIPSE as integer =  2
	'#define  CV_SHAPE_CUSTOM    100
	public const  CV_SHAPE_CUSTOM as integer =  100

	'/* creates structuring element used for morphological operations */
	'CVAPI(IplConvKernel*)  cvCreateStructuringElementEx(
	'            int cols, int  rows, int  anchor_x, int  anchor_y,
	'            int shape, int* values CV_DEFAULT(NULL) );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvCreateStructuringElementEx(byval cols as integer,byval rows as integer,byval anchor_x as integer,byval anchor_y as integer,byval shape as integer,byval values as integer()) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvCreateStructuringElementEx(byval cols as integer,byval rows as integer,byval anchor_x as integer,byval anchor_y as integer,byval shape as integer,byref values as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvCreateStructuringElementEx(byval cols as integer,byval rows as integer,byval anchor_x as integer,byval anchor_y as integer,byval shape as integer,byval values as intptr) as IntPtr
	end function

	'/* releases structuring element */
	'CVAPI(void)  cvReleaseStructuringElement( IplConvKernel** element );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvReleaseStructuringElement(byref element as intptr)
	end sub

	'/* erodes input image (applies minimum filter) one or more times.
	'   If element pointer is NULL, 3x3 rectangular element is used */
	'CVAPI(void)  cvErode( const CvArr* src, CvArr* dst,
	'                      IplConvKernel* element CV_DEFAULT(NULL),
	'                      int iterations CV_DEFAULT(1) );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvErode(byval src as intptr,byval dst as intptr,byref element as IplConvKernel,byval iterations as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvErode(byval src as intptr,byval dst as intptr,byval element as intptr,byval iterations as integer)
	end sub

	'/* dilates input image (applies maximum filter) one or more times.
	'   If element pointer is NULL, 3x3 rectangular element is used */
	'CVAPI(void)  cvDilate( const CvArr* src, CvArr* dst,
	'                       IplConvKernel* element CV_DEFAULT(NULL),
	'                       int iterations CV_DEFAULT(1) );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvDilate(byval src as intptr,byval dst as intptr,byref element as IplConvKernel,byval iterations as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvDilate(byval src as intptr,byval dst as intptr,byval element as intptr,byval iterations as integer)
	end sub

	'#define CV_MOP_OPEN         2
	public const  CV_MOP_OPEN as integer =  2
	'#define CV_MOP_CLOSE        3
	public const  CV_MOP_CLOSE as integer =  3
	'#define CV_MOP_GRADIENT     4
	public const  CV_MOP_GRADIENT as integer =  4
	'#define CV_MOP_TOPHAT       5
	public const  CV_MOP_TOPHAT as integer =  5
	'#define CV_MOP_BLACKHAT     6
	public const  CV_MOP_BLACKHAT as integer =  6

	'/* Performs complex morphological transformation */
	'CVAPI(void)  cvMorphologyEx( const CvArr* src, CvArr* dst,
	'                             CvArr* temp, IplConvKernel* element,
	'                             int operation, int iterations CV_DEFAULT(1) );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvMorphologyEx(byval src as intptr,byval dst as intptr,byval temp as intptr,byref element as IplConvKernel,byval operation as integer,byval iterations as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvMorphologyEx(byval src as intptr,byval dst as intptr,byval temp as intptr,byval element as intptr,byval operation as integer,byval iterations as integer)
	end sub

	'/* Calculates all spatial and central moments up to the 3rd order */
	'CVAPI(void) cvMoments( const CvArr* arr, CvMoments* moments, int binary CV_DEFAULT(0));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvMoments(byval arr as intptr,byref moments as CvMoments,byval binary as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvMoments(byval arr as intptr,byval moments as intptr,byval binary as integer)
	end sub

	'/* Retrieve particular spatial, central or normalized central moments */
	'CVAPI(double)  cvGetSpatialMoment( CvMoments* moments, int x_order, int y_order );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvGetSpatialMoment(byref moments as CvMoments,byval x_order as integer,byval y_order as integer) as double
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvGetSpatialMoment(byval moments as intptr,byval x_order as integer,byval y_order as integer) as double
	end function
	'CVAPI(double)  cvGetCentralMoment( CvMoments* moments, int x_order, int y_order );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvGetCentralMoment(byref moments as CvMoments,byval x_order as integer,byval y_order as integer) as double
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvGetCentralMoment(byval moments as intptr,byval x_order as integer,byval y_order as integer) as double
	end function
	'CVAPI(double)  cvGetNormalizedCentralMoment( CvMoments* moments,
	'                                             int x_order, int y_order );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvGetNormalizedCentralMoment(byref moments as CvMoments,byval x_order as integer,byval y_order as integer) as double
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvGetNormalizedCentralMoment(byval moments as intptr,byval x_order as integer,byval y_order as integer) as double
	end function

	'/* Calculates 7 Hu's invariants from precalculated spatial and central moments */
	'CVAPI(void) cvGetHuMoments( CvMoments*  moments, CvHuMoments*  hu_moments );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetHuMoments(byref moments as CvMoments,byref hu_moments as CvHuMoments)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetHuMoments(byval moments as intptr,byref hu_moments as CvHuMoments)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetHuMoments(byref moments as CvMoments,byval hu_moments as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetHuMoments(byval moments as intptr,byval hu_moments as intptr)
	end sub

	'/*********************************** data sampling **************************************/

	'/* Fetches pixels that belong to the specified line segment and stores them to the buffer.
	'   Returns the number of retrieved points. */
	'CVAPI(int)  cvSampleLine( const CvArr* image, CvPoint pt1, CvPoint pt2, void* buffer,
	'                          int connectivity CV_DEFAULT(8));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvSampleLine(byval image as intptr,byval pt1 as CvPoint,byval pt2 as CvPoint,byval buffer as intptr,byval connectivity as integer) as integer
	end function

	'/* Retrieves the rectangular image region with specified center from the input array.
	' dst(x,y) <- src(x + center.x - dst_width/2, y + center.y - dst_height/2).
	' Values of pixels with fractional coordinates are retrieved using bilinear interpolation*/
	'CVAPI(void)  cvGetRectSubPix( const CvArr* src, CvArr* dst, CvPoint2D32f center );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetRectSubPix(byval src as intptr,byval dst as intptr,byval center as CvPoint2D32f)
	end sub


	'/* Retrieves quadrangle from the input array.
	'    matrixarr = ( a11  a12 | b1 )   dst(x,y) <- src(A[x y]' + b)
	'                ( a21  a22 | b2 )   (bilinear interpolation is used to retrieve pixels
	'                                     with fractional coordinates)
	'*/
	'CVAPI(void)  cvGetQuadrangleSubPix( const CvArr* src, CvArr* dst,
	'                                    const CvMat* map_matrix );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetQuadrangleSubPix(byval src as intptr,byval dst as intptr,byref map_matrix as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetQuadrangleSubPix(byval src as intptr,byval dst as intptr,byval map_matrix as intptr)
	end sub

	'/* Methods for comparing two array */
	'#define  CV_TM_SQDIFF        0
	public const  CV_TM_SQDIFF as integer =  0
	'#define  CV_TM_SQDIFF_NORMED 1
	public const  CV_TM_SQDIFF_NORMED as integer =  1
	'#define  CV_TM_CCORR         2
	public const  CV_TM_CCORR as integer =  2
	'#define  CV_TM_CCORR_NORMED  3
	public const  CV_TM_CCORR_NORMED as integer =  3
	'#define  CV_TM_CCOEFF        4
	public const  CV_TM_CCOEFF as integer =  4
	'#define  CV_TM_CCOEFF_NORMED 5
	public const  CV_TM_CCOEFF_NORMED as integer =  5

	'/* Measures similarity between template and overlapped windows in the source image
	'   and fills the resultant image with the measurements */
	'CVAPI(void)  cvMatchTemplate( const CvArr* image, const CvArr* templ,
	'                              CvArr* result, int method );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvMatchTemplate(byval image as intptr,byval templ as intptr,byval result as intptr,byval method as integer)
	end sub

	'/* Computes earth mover distance between
	'   two weighted point sets (called signatures) */
	'CVAPI(float)  cvCalcEMD2( const CvArr* signature1,
	'                          const CvArr* signature2,
	'                          int distance_type,
	'                          CvDistanceFunction distance_func CV_DEFAULT(NULL),
	'                          const CvArr* cost_matrix CV_DEFAULT(NULL),
	'                          CvArr* flow CV_DEFAULT(NULL),
	'                          float* lower_bound CV_DEFAULT(NULL),
	'                          void* userdata CV_DEFAULT(NULL));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvCalcEMD2(byval signature1 as intptr,byval signature2 as intptr,byval distance_type as integer,byval distance_func as intptr,byval cost_matrix as intptr,byval flow as intptr,byval lower_bound as single(),byval userdata as intptr) as single
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvCalcEMD2(byval signature1 as intptr,byval signature2 as intptr,byval distance_type as integer,byval distance_func as intptr,byval cost_matrix as intptr,byval flow as intptr,byref lower_bound as single,byval userdata as intptr) as single
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvCalcEMD2(byval signature1 as intptr,byval signature2 as intptr,byval distance_type as integer,byval distance_func as intptr,byval cost_matrix as intptr,byval flow as intptr,byval lower_bound as intptr,byval userdata as intptr) as single
	end function

	'/****************************************************************************************\
	'*                              Contours retrieving                                       *
	'\****************************************************************************************/

	'/* Retrieves outer and optionally inner boundaries of white (non-zero) connected
	'   components in the black (zero) background */
	'CVAPI(int)  cvFindContours( CvArr* image, CvMemStorage* storage, CvSeq** first_contour,
	'                            int header_size CV_DEFAULT(sizeof(CvContour)),
	'                            int mode CV_DEFAULT(CV_RETR_LIST),
	'                            int method CV_DEFAULT(CV_CHAIN_APPROX_SIMPLE),
	'                            CvPoint offset CV_DEFAULT(cvPoint(0,0)));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvFindContours(byval image as intptr,byref storage as CvMemStorage,ByRef first_contour As intptr,byval header_size as integer,byval mode as integer,byval method as integer,byval offset as CvPoint) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvFindContours(byval image as intptr,byval storage as intptr,ByRef first_contour As intptr,byval header_size as integer,byval mode as integer,byval method as integer,byval offset as CvPoint) as integer
	end function


	'/* Initalizes contour retrieving process.
	'   Calls cvStartFindContours.
	'   Calls cvFindNextContour until null pointer is returned
	'   or some other condition becomes true.
	'   Calls cvEndFindContours at the end. */
	'CVAPI(CvContourScanner)  cvStartFindContours( CvArr* image, CvMemStorage* storage,
	'                            int header_size CV_DEFAULT(sizeof(CvContour)),
	'                            int mode CV_DEFAULT(CV_RETR_LIST),
	'                            int method CV_DEFAULT(CV_CHAIN_APPROX_SIMPLE),
	'                            CvPoint offset CV_DEFAULT(cvPoint(0,0)));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvStartFindContours(byval image as intptr,byref storage as CvMemStorage,byval header_size as integer,byval mode as integer,byval method as integer,byval offset as CvPoint) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvStartFindContours(byval image as intptr,byval storage as intptr,byval header_size as integer,byval mode as integer,byval method as integer,byval offset as CvPoint) as IntPtr
	end function

	'/* Retrieves next contour */
	'CVAPI(CvSeq*)  cvFindNextContour( CvContourScanner scanner );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvFindNextContour(byval scanner as intptr) as IntPtr
	end function


	'/* Substitutes the last retrieved contour with the new one
	'   (if the substitutor is null, the last retrieved contour is removed from the tree) */
	'CVAPI(void)   cvSubstituteContour( CvContourScanner scanner, CvSeq* new_contour );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSubstituteContour(byval scanner as intptr,byref new_contour as CvSeq)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSubstituteContour(byval scanner as intptr,byval new_contour as intptr)
	end sub


	'/* Releases contour scanner and returns pointer to the first outer contour */
	'CVAPI(CvSeq*)  cvEndFindContours( CvContourScanner* scanner );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvEndFindContours(byval scanner as intptr) as IntPtr
	end function

	'/* Approximates a single Freeman chain or a tree of chains to polygonal curves */
	'CVAPI(CvSeq*) cvApproxChains( CvSeq* src_seq, CvMemStorage* storage,
	'                            int method CV_DEFAULT(CV_CHAIN_APPROX_SIMPLE),
	'                            double parameter CV_DEFAULT(0),
	'                            int  minimal_perimeter CV_DEFAULT(0),
	'                            int  recursive CV_DEFAULT(0));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvApproxChains(byref src_seq as CvSeq,byref storage as CvMemStorage,byval method as integer,byval parameter as double,byval minimal_perimeter as integer,byval recursive as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvApproxChains(byval src_seq as intptr,byref storage as CvMemStorage,byval method as integer,byval parameter as double,byval minimal_perimeter as integer,byval recursive as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvApproxChains(byref src_seq as CvSeq,byval storage as intptr,byval method as integer,byval parameter as double,byval minimal_perimeter as integer,byval recursive as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvApproxChains(byval src_seq as intptr,byval storage as intptr,byval method as integer,byval parameter as double,byval minimal_perimeter as integer,byval recursive as integer) as IntPtr
	end function


	'/* Initalizes Freeman chain reader.
	'   The reader is used to iteratively get coordinates of all the chain points.
	'   If the Freeman codes should be read as is, a simple sequence reader should be used */
	'CVAPI(void) cvStartReadChainPoints( CvChain* chain, CvChainPtReader* reader );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvStartReadChainPoints(byref chain as CvChain,byref reader as CvChainPtReader)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvStartReadChainPoints(byval chain as intptr,byref reader as CvChainPtReader)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvStartReadChainPoints(byref chain as CvChain,byval reader as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvStartReadChainPoints(byval chain as intptr,byval reader as intptr)
	end sub

	'/* Retrieves the next chain point */
	'CVAPI(CvPoint) cvReadChainPoint( CvChainPtReader* reader );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvReadChainPoint(byref reader as CvChainPtReader) as CvPoint
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvReadChainPoint(byval reader as intptr) as CvPoint
	end function


	'/****************************************************************************************\
	'*                                  Motion Analysis                                       *
	'\****************************************************************************************/

	'/************************************ optical flow ***************************************/

	'/* Calculates optical flow for 2 images using classical Lucas & Kanade algorithm */
	'CVAPI(void)  cvCalcOpticalFlowLK( const CvArr* prev, const CvArr* curr,
	'                                  CvSize win_size, CvArr* velx, CvArr* vely );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowLK(byval prev as intptr,byval curr as intptr,byval win_size as CvSize,byval velx as intptr,byval vely as intptr)
	end sub

	'/* Calculates optical flow for 2 images using block matching algorithm */
	'CVAPI(void)  cvCalcOpticalFlowBM( const CvArr* prev, const CvArr* curr,
	'                                  CvSize block_size, CvSize shift_size,
	'                                  CvSize max_range, int use_previous,
	'                                  CvArr* velx, CvArr* vely );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowBM(byval prev as intptr,byval curr as intptr,byval block_size as CvSize,byval shift_size as CvSize,byval max_range as CvSize,byval use_previous as integer,byval velx as intptr,byval vely as intptr)
	end sub

	'/* Calculates Optical flow for 2 images using Horn & Schunck algorithm */
	'CVAPI(void)  cvCalcOpticalFlowHS( const CvArr* prev, const CvArr* curr,
	'                                  int use_previous, CvArr* velx, CvArr* vely,
	'                                  double lambda, CvTermCriteria criteria );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowHS(byval prev as intptr,byval curr as intptr,byval use_previous as integer,byval velx as intptr,byval vely as intptr,byval lambda as double,byval criteria as CvTermCriteria)
	end sub

	'#define  CV_LKFLOW_PYR_A_READY       1
	public const  CV_LKFLOW_PYR_A_READY as integer =  1
	'#define  CV_LKFLOW_PYR_B_READY       2
	public const  CV_LKFLOW_PYR_B_READY as integer =  2
	'#define  CV_LKFLOW_INITIAL_GUESSES   4
	public const  CV_LKFLOW_INITIAL_GUESSES as integer =  4

	'/* It is Lucas & Kanade method, modified to use pyramids.
	'   Also it does several iterations to get optical flow for
	'   every point at every pyramid level.
	'   Calculates optical flow between two images for certain set of points (i.e.
	'   it is a "sparse" optical flow, which is opposite to the previous 3 methods) */
	'CVAPI(void)  cvCalcOpticalFlowPyrLK( const CvArr*  prev, const CvArr*  curr,
	'                                     CvArr*  prev_pyr, CvArr*  curr_pyr,
	'                                     const CvPoint2D32f* prev_features,
	'                                     CvPoint2D32f* curr_features,
	'                                     int       count,
	'                                     CvSize    win_size,
	'                                     int       level,
	'                                     char*     status,
	'                                     float*    track_error,
	'                                     CvTermCriteria criteria,
	'                                     int       flags );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byref prev_features as CvPoint2D32f,byref curr_features as CvPoint2D32f,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as string,byval track_error as single(),byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byval prev_features as intptr,byref curr_features as CvPoint2D32f,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as string,byval track_error as single(),byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byref prev_features as CvPoint2D32f,byval curr_features as intptr,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as string,byval track_error as single(),byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byval prev_features as intptr,byval curr_features as intptr,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as string,byval track_error as single(),byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byref prev_features as CvPoint2D32f,byref curr_features as CvPoint2D32f,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as byte(),byval track_error as single(),byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byval prev_features as intptr,byref curr_features as CvPoint2D32f,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as byte(),byval track_error as single(),byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byref prev_features as CvPoint2D32f,byval curr_features as intptr,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as byte(),byval track_error as single(),byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byval prev_features as intptr,byval curr_features as intptr,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as byte(),byval track_error as single(),byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byref prev_features as CvPoint2D32f,byref curr_features as CvPoint2D32f,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as intptr,byval track_error as single(),byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byval prev_features as intptr,byref curr_features as CvPoint2D32f,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as intptr,byval track_error as single(),byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byref prev_features as CvPoint2D32f,byval curr_features as intptr,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as intptr,byval track_error as single(),byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byval prev_features as intptr,byval curr_features as intptr,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as intptr,byval track_error as single(),byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byref prev_features as CvPoint2D32f,byref curr_features as CvPoint2D32f,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as string,byref track_error as single,byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byval prev_features as intptr,byref curr_features as CvPoint2D32f,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as string,byref track_error as single,byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byref prev_features as CvPoint2D32f,byval curr_features as intptr,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as string,byref track_error as single,byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byval prev_features as intptr,byval curr_features as intptr,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as string,byref track_error as single,byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byref prev_features as CvPoint2D32f,byref curr_features as CvPoint2D32f,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as byte(),byref track_error as single,byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byval prev_features as intptr,byref curr_features as CvPoint2D32f,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as byte(),byref track_error as single,byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byref prev_features as CvPoint2D32f,byval curr_features as intptr,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as byte(),byref track_error as single,byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byval prev_features as intptr,byval curr_features as intptr,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as byte(),byref track_error as single,byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byref prev_features as CvPoint2D32f,byref curr_features as CvPoint2D32f,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as intptr,byref track_error as single,byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byval prev_features as intptr,byref curr_features as CvPoint2D32f,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as intptr,byref track_error as single,byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byref prev_features as CvPoint2D32f,byval curr_features as intptr,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as intptr,byref track_error as single,byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byval prev_features as intptr,byval curr_features as intptr,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as intptr,byref track_error as single,byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byref prev_features as CvPoint2D32f,byref curr_features as CvPoint2D32f,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as string,byval track_error as intptr,byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byval prev_features as intptr,byref curr_features as CvPoint2D32f,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as string,byval track_error as intptr,byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byref prev_features as CvPoint2D32f,byval curr_features as intptr,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as string,byval track_error as intptr,byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byval prev_features as intptr,byval curr_features as intptr,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as string,byval track_error as intptr,byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byref prev_features as CvPoint2D32f,byref curr_features as CvPoint2D32f,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as byte(),byval track_error as intptr,byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byval prev_features as intptr,byref curr_features as CvPoint2D32f,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as byte(),byval track_error as intptr,byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byref prev_features as CvPoint2D32f,byval curr_features as intptr,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as byte(),byval track_error as intptr,byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byval prev_features as intptr,byval curr_features as intptr,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as byte(),byval track_error as intptr,byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byref prev_features as CvPoint2D32f,byref curr_features as CvPoint2D32f,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as intptr,byval track_error as intptr,byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byval prev_features as intptr,byref curr_features as CvPoint2D32f,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as intptr,byval track_error as intptr,byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byref prev_features as CvPoint2D32f,byval curr_features as intptr,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as intptr,byval track_error as intptr,byval criteria as CvTermCriteria,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcOpticalFlowPyrLK(byval prev as intptr,byval curr as intptr,byval prev_pyr as intptr,byval curr_pyr as intptr,byval prev_features as intptr,byval curr_features as intptr,byval count as integer,byval win_size as CvSize,byval level as integer,byval status as intptr,byval track_error as intptr,byval criteria as CvTermCriteria,byval flags as integer)
	end sub


	'/* Modification of a previous sparse optical flow algorithm to calculate
	'   affine flow */
	'/*CVAPI  void  cvCalcAffineFlowPyrLK( const CvArr*  prev, const CvArr*  curr,
	'                                     CvArr*  prev_pyr, CvArr*  curr_pyr,
	'                                     CvPoint2D32f* prev_features,
	'                                     CvPoint2D32f* curr_features,
	'                                     float*  matrices, int  count,
	'                                     CvSize  win_size, int  level,
	'                                     char*  status, float* track_error,
	'                                     CvTermCriteria criteria, int flags );*/

	'/********************************* motion templates *************************************/

	'/****************************************************************************************\
	'*        All the motion template functions work only with single channel images.         *
	'*        Silhouette image must have depth IPL_DEPTH_8U or IPL_DEPTH_8S                   *
	'*        Motion history image must have depth IPL_DEPTH_32F,                             *
	'*        Gradient mask - IPL_DEPTH_8U or IPL_DEPTH_8S,                                   *
	'*        Motion orientation image - IPL_DEPTH_32F                                        *
	'*        Segmentation mask - IPL_DEPTH_32F                                               *
	'*        All the angles are in degrees, all the times are in milliseconds                *
	'\****************************************************************************************/

	'/* Updates motion history image given motion silhouette */
	'CVAPI(void)    cvUpdateMotionHistory( const CvArr* silhouette, CvArr* mhi,
	'                                      double timestamp, double duration );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvUpdateMotionHistory(byval silhouette as intptr,byval mhi as intptr,byval timestamp as double,byval duration as double)
	end sub

	'/* Calculates gradient of the motion history image and fills
	'   a mask indicating where the gradient is valid */
	'CVAPI(void)    cvCalcMotionGradient( const CvArr* mhi, CvArr* mask, CvArr* orientation,
	'                                     double delta1, double delta2,
	'                                     int aperture_size CV_DEFAULT(3));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcMotionGradient(byval mhi as intptr,byval mask as intptr,byval orientation as intptr,byval delta1 as double,byval delta2 as double,byval aperture_size as integer)
	end sub

	'/* Calculates average motion direction within a selected motion region 
	'   (region can be selected by setting ROIs and/or by composing a valid gradient mask
	'   with the region mask) */
	'CVAPI(double)  cvCalcGlobalOrientation( const CvArr* orientation, const CvArr* mask,
	'                                        const CvArr* mhi, double timestamp,
	'                                        double duration );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvCalcGlobalOrientation(byval orientation as intptr,byval mask as intptr,byval mhi as intptr,byval timestamp as double,byval duration as double) as double
	end function

	'/* Splits a motion history image into a few parts corresponding to separate independent motions
	'   (e.g. left hand, right hand) */
	'CVAPI(CvSeq*)  cvSegmentMotion( const CvArr* mhi, CvArr* seg_mask,
	'                                CvMemStorage* storage,
	'                                double timestamp, double seg_thresh );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvSegmentMotion(byval mhi as intptr,byval seg_mask as intptr,byref storage as CvMemStorage,byval timestamp as double,byval seg_thresh as double) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvSegmentMotion(byval mhi as intptr,byval seg_mask as intptr,byval storage as intptr,byval timestamp as double,byval seg_thresh as double) as IntPtr
	end function

	'/*********************** Background statistics accumulation *****************************/

	'/* Adds image to accumulator */
	'CVAPI(void)  cvAcc( const CvArr* image, CvArr* sum,
	'                    const CvArr* mask CV_DEFAULT(NULL) );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvAcc(byval image as intptr,byval sum as intptr,byval mask as intptr)
	end sub

	'/* Adds squared image to accumulator */
	'CVAPI(void)  cvSquareAcc( const CvArr* image, CvArr* sqsum,
	'                          const CvArr* mask CV_DEFAULT(NULL) );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSquareAcc(byval image as intptr,byval sqsum as intptr,byval mask as intptr)
	end sub

	'/* Adds a product of two images to accumulator */
	'CVAPI(void)  cvMultiplyAcc( const CvArr* image1, const CvArr* image2, CvArr* acc,
	'                            const CvArr* mask CV_DEFAULT(NULL) );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvMultiplyAcc(byval image1 as intptr,byval image2 as intptr,byval acc as intptr,byval mask as intptr)
	end sub

	'/* Adds image to accumulator with weights: acc = acc*(1-alpha) + image*alpha */
	'CVAPI(void)  cvRunningAvg( const CvArr* image, CvArr* acc, double alpha,
	'                           const CvArr* mask CV_DEFAULT(NULL) );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvRunningAvg(byval image as intptr,byval acc as intptr,byval alpha as double,byval mask as intptr)
	end sub


	'/****************************************************************************************\
	'*                                       Tracking                                         *
	'\****************************************************************************************/

	'/* Implements CAMSHIFT algorithm - determines object position, size and orientation
	'   from the object histogram back project (extension of meanshift) */
	'CVAPI(int)  cvCamShift( const CvArr* prob_image, CvRect  window,
	'                       CvTermCriteria criteria, CvConnectedComp* comp,
	'                       CvBox2D* box CV_DEFAULT(NULL) );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvCamShift(byval prob_image as intptr,byval window as CvRect,byval criteria as CvTermCriteria,byref comp as CvConnectedComp,byref box as CvBox2D) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvCamShift(byval prob_image as intptr,byval window as CvRect,byval criteria as CvTermCriteria,byval comp as intptr,byref box as CvBox2D) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvCamShift(byval prob_image as intptr,byval window as CvRect,byval criteria as CvTermCriteria,byref comp as CvConnectedComp,byval box as intptr) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvCamShift(byval prob_image as intptr,byval window as CvRect,byval criteria as CvTermCriteria,byval comp as intptr,byval box as intptr) as integer
	end function

	'/* Implements MeanShift algorithm - determines object position
	'   from the object histogram back project */
	'CVAPI(int)  cvMeanShift( const CvArr* prob_image, CvRect  window,
	'                        CvTermCriteria criteria, CvConnectedComp* comp );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMeanShift(byval prob_image as intptr,byval window as CvRect,byval criteria as CvTermCriteria,byref comp as CvConnectedComp) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMeanShift(byval prob_image as intptr,byval window as CvRect,byval criteria as CvTermCriteria,byval comp as intptr) as integer
	end function

	'/* Creates ConDensation filter state */
	'CVAPI(CvConDensation*)  cvCreateConDensation( int dynam_params,
	'                                             int measure_params,
	'                                             int sample_count );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvCreateConDensation(byval dynam_params as integer,byval measure_params as integer,byval sample_count as integer) as IntPtr
	end function

	'/* Releases ConDensation filter state */
	'CVAPI(void)  cvReleaseConDensation( CvConDensation** condens );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvReleaseConDensation(byref condens as intptr)
	end sub

	'/* Updates ConDensation filter by time (predict future state of the system) */
	'CVAPI(void)  cvConDensUpdateByTime( CvConDensation* condens);
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvConDensUpdateByTime(byref condens as CvConDensation)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvConDensUpdateByTime(byval condens as intptr)
	end sub

	'/* Initializes ConDensation filter samples  */
	'CVAPI(void)  cvConDensInitSampleSet( CvConDensation* condens, CvMat* lower_bound, CvMat* upper_bound );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvConDensInitSampleSet(byref condens as CvConDensation,byref lower_bound as CvMat,byref upper_bound as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvConDensInitSampleSet(byval condens as intptr,byref lower_bound as CvMat,byref upper_bound as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvConDensInitSampleSet(byref condens as CvConDensation,byval lower_bound as intptr,byref upper_bound as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvConDensInitSampleSet(byval condens as intptr,byval lower_bound as intptr,byref upper_bound as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvConDensInitSampleSet(byref condens as CvConDensation,byref lower_bound as CvMat,byval upper_bound as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvConDensInitSampleSet(byval condens as intptr,byref lower_bound as CvMat,byval upper_bound as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvConDensInitSampleSet(byref condens as CvConDensation,byval lower_bound as intptr,byval upper_bound as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvConDensInitSampleSet(byval condens as intptr,byval lower_bound as intptr,byval upper_bound as intptr)
	end sub

	'/* Creates Kalman filter and sets A, B, Q, R and state to some initial values */
	'CVAPI(CvKalman*) cvCreateKalman( int dynam_params, int measure_params,
	'                                int control_params CV_DEFAULT(0));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvCreateKalman(byval dynam_params as integer,byval measure_params as integer,byval control_params as integer) as IntPtr
	end function

	'/* Releases Kalman filter state */
	'CVAPI(void)  cvReleaseKalman( CvKalman** kalman);
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvReleaseKalman(byref kalman as intptr)
	end sub

	'/* Updates Kalman filter by time (predicts future state of the system) */
	'CVAPI(const CvMat*)  cvKalmanPredict( CvKalman* kalman,
	'                                     const CvMat* control CV_DEFAULT(NULL));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvKalmanPredict(byref kalman as CvKalman,byref control as CvMat) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvKalmanPredict(byval kalman as intptr,byref control as CvMat) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvKalmanPredict(byref kalman as CvKalman,byval control as intptr) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvKalmanPredict(byval kalman as intptr,byval control as intptr) as IntPtr
	end function

	'/* Updates Kalman filter by measurement
	'   (corrects state of the system and internal matrices) */
	'CVAPI(const CvMat*)  cvKalmanCorrect( CvKalman* kalman, const CvMat* measurement );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvKalmanCorrect(byref kalman as CvKalman,byref measurement as CvMat) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvKalmanCorrect(byval kalman as intptr,byref measurement as CvMat) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvKalmanCorrect(byref kalman as CvKalman,byval measurement as intptr) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvKalmanCorrect(byval kalman as intptr,byval measurement as intptr) as IntPtr
	end function

	'/****************************************************************************************\
	'*                              Planar subdivisions                                       *
	'\****************************************************************************************/

	'/* Initializes Delaunay triangulation */
	'CVAPI(void)  cvInitSubdivDelaunay2D( CvSubdiv2D* subdiv, CvRect rect );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvInitSubdivDelaunay2D(byref subdiv as CvSubdiv2D,byval rect as CvRect)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvInitSubdivDelaunay2D(byval subdiv as intptr,byval rect as CvRect)
	end sub

	'/* Creates new subdivision */
	'CVAPI(CvSubdiv2D*)  cvCreateSubdiv2D( int subdiv_type, int header_size,
	'                                      int vtx_size, int quadedge_size,
	'                                      CvMemStorage* storage );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvCreateSubdiv2D(byval subdiv_type as integer,byval header_size as integer,byval vtx_size as integer,byval quadedge_size as integer,byref storage as CvMemStorage) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvCreateSubdiv2D(byval subdiv_type as integer,byval header_size as integer,byval vtx_size as integer,byval quadedge_size as integer,byval storage as intptr) as IntPtr
	end function

	'/************************* high-level subdivision functions ***************************/

	'/* Simplified Delaunay diagram creation */
	'CV_INLINE  CvSubdiv2D* cvCreateSubdivDelaunay2D( CvRect rect, CvMemStorage* storage )
	'{
	'    CvSubdiv2D* subdiv = cvCreateSubdiv2D( CV_SEQ_KIND_SUBDIV2D, sizeof(*subdiv),
	'                         sizeof(CvSubdiv2DPoint), sizeof(CvQuadEdge2D), storage );

	'    cvInitSubdivDelaunay2D( subdiv, rect );
	'    return subdiv;
	'}
    Public Function cvCreateSubdivDelaunay2D(ByVal rect As CvRect, ByVal storage As IntPtr) As IntPtr

        Dim subdiv As IntPtr
        subdiv = cvCreateSubdiv2D(CV_SEQ_KIND_SUBDIV2D, _
            4, _
            Marshal.SizeOf(GetType(CvSubdiv2DPoint)), _
            Marshal.SizeOf(GetType(CvQuadEdge2D)), _
            storage)

        cvInitSubdivDelaunay2D(subdiv, rect)

        Return subdiv
    End Function




	'/* Inserts new point to the Delaunay triangulation */
	'CVAPI(CvSubdiv2DPoint*)  cvSubdivDelaunay2DInsert( CvSubdiv2D* subdiv, CvPoint2D32f pt);
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvSubdivDelaunay2DInsert(byref subdiv as CvSubdiv2D,byval pt as CvPoint2D32f) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvSubdivDelaunay2DInsert(byval subdiv as intptr,byval pt as CvPoint2D32f) as IntPtr
	end function

	'/* Locates a point within the Delaunay triangulation (finds the edge
	'   the point is left to or belongs to, or the triangulation point the given
	'   point coinsides with */
	'CVAPI(CvSubdiv2DPointLocation)  cvSubdiv2DLocate(
	'                               CvSubdiv2D* subdiv, CvPoint2D32f pt,
	'                               CvSubdiv2DEdge* edge,
	'                               CvSubdiv2DPoint** vertex CV_DEFAULT(NULL) );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvSubdiv2DLocate(byref subdiv as CvSubdiv2D,byval pt as CvPoint2D32f,byref edge as integer,byval vertex as intptr) as CvSubdiv2DPointLocation
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvSubdiv2DLocate(byval subdiv as intptr,byval pt as CvPoint2D32f,byref edge as integer,byval vertex as intptr) as CvSubdiv2DPointLocation
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvSubdiv2DLocate(byref subdiv as CvSubdiv2D,byval pt as CvPoint2D32f,byval edge as intptr,byval vertex as intptr) as CvSubdiv2DPointLocation
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvSubdiv2DLocate(byval subdiv as intptr,byval pt as CvPoint2D32f,byval edge as intptr,byval vertex as intptr) as CvSubdiv2DPointLocation
	end function

	'/* Calculates Voronoi tesselation (i.e. coordinates of Voronoi points) */
	'CVAPI(void)  cvCalcSubdivVoronoi2D( CvSubdiv2D* subdiv );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcSubdivVoronoi2D(byref subdiv as CvSubdiv2D)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcSubdivVoronoi2D(byval subdiv as intptr)
	end sub


	'/* Removes all Voronoi points from the tesselation */
	'CVAPI(void)  cvClearSubdivVoronoi2D( CvSubdiv2D* subdiv );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvClearSubdivVoronoi2D(byref subdiv as CvSubdiv2D)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvClearSubdivVoronoi2D(byval subdiv as intptr)
	end sub


	'/* Finds the nearest to the given point vertex in subdivision. */
	'CVAPI(CvSubdiv2DPoint*) cvFindNearestPoint2D( CvSubdiv2D* subdiv, CvPoint2D32f pt );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvFindNearestPoint2D(byref subdiv as CvSubdiv2D,byval pt as CvPoint2D32f) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvFindNearestPoint2D(byval subdiv as intptr,byval pt as CvPoint2D32f) as IntPtr
	end function


	'/************ Basic quad-edge navigation and operations ************/

	'CV_INLINE  CvSubdiv2DEdge  cvSubdiv2DNextEdge( CvSubdiv2DEdge edge )
	'{
	'    return  CV_SUBDIV2D_NEXT_EDGE(edge);
	'}
    Public Function cvSubdiv2DNextEdge(ByVal edge As Integer) As Integer
        Return cvSubdiv2DNextEdge(edge)
    End Function
    Public Function cvSubdiv2DNextEdge(ByVal edge As IntPtr) As Integer
        Return CV_SUBDIV2D_NEXT_EDGE(edge.ToInt32)
    End Function




	'CV_INLINE  CvSubdiv2DEdge  cvSubdiv2DRotateEdge( CvSubdiv2DEdge edge, int rotate )
	'{
	'    return  (edge & ~3) + ((edge + rotate) & 3);
	'}
    Public Function cvSubdiv2DRotateEdge(ByVal edge As Integer, ByVal rotate As Integer) As Integer
        Return (edge And &HFFFFFFFC) + (edge + rotate) And 3
    End Function



	'CV_INLINE  CvSubdiv2DEdge  cvSubdiv2DSymEdge( CvSubdiv2DEdge edge )
	'{
	'    return edge ^ 2;
	'}
    Public Function cvSubdiv2DSymEdge(ByVal edge As Integer) As Integer
        Return edge Xor 2
    End Function



	'CV_INLINE  CvSubdiv2DEdge  cvSubdiv2DGetEdge( CvSubdiv2DEdge edge, CvNextEdgeType type )
	'{
	'    CvQuadEdge2D* e = (CvQuadEdge2D*)(edge & ~3);
	'    edge = e->next[(edge + (int)type) & 3];
	'    return  (edge & ~3) + ((edge + ((int)type >> 4)) & 3);
	'}
    Public Function cvSubdiv2DGetEdge(ByVal edge As Integer, ByVal [type] As CvNextEdgeType) As Integer
        Dim ptr As IntPtr = CType(edge And &HFFFFFFFC, IntPtr)
        Dim e As CvQuadEdge2D = CType(Marshal.PtrToStructure(ptr, GetType(CvQuadEdge2D)), CvQuadEdge2D)
        edge = e.next((edge + [type]) And 3)
        Return (edge And &HFFFFFFFC) + ((edge + ([type] >> 4)) And 3)
    End Function




	'CV_INLINE  CvSubdiv2DPoint*  cvSubdiv2DEdgeOrg( CvSubdiv2DEdge edge )
	'{
	'    CvQuadEdge2D* e = (CvQuadEdge2D*)(edge & ~3);
	'    return (CvSubdiv2DPoint*)e->pt[edge & 3];
	'}
    Public Function cvSubdiv2DEdgeOrg(ByVal edge As Integer) As IntPtr
        Dim ptr As IntPtr = CType(edge And &HFFFFFFC, IntPtr)
        Dim e As CvQuadEdge2D = CType(Marshal.PtrToStructure(ptr, GetType(CvQuadEdge2D)), CvQuadEdge2D)
        Return e.pt(edge And 3)
    End Function




	'CV_INLINE  CvSubdiv2DPoint*  cvSubdiv2DEdgeDst( CvSubdiv2DEdge edge )
	'{
	'    CvQuadEdge2D* e = (CvQuadEdge2D*)(edge & ~3);
	'    return (CvSubdiv2DPoint*)e->pt[(edge + 2) & 3];
	'}
    Public Function cvSubdiv2DEdgeDst(ByVal edge As Integer) As IntPtr
        Dim ptr As IntPtr = CType(edge And &HFFFFFFC, IntPtr)
        Dim e As CvQuadEdge2D = CType(Marshal.PtrToStructure(ptr, GetType(CvQuadEdge2D)), CvQuadEdge2D)
        Return e.pt((edge + 2) And 3)
    End Function




	'CV_INLINE  double  cvTriangleArea( CvPoint2D32f a, CvPoint2D32f b, CvPoint2D32f c )
	'{
	'    return (b.x - a.x) * (c.y - a.y) - (b.y - a.y) * (c.x - a.x);
	'}
    Public Function cvTriangleArea(ByVal a As CvPoint2D32f, ByVal b As CvPoint2D32f, ByVal c As CvPoint2D32f) As Double
        Return (b.x - a.x) * (c.y - a.y) - (b.y - a.y) * (c.x - a.x)
    End Function




	'/****************************************************************************************\
	'*                            Contour Processing and Shape Analysis                       *
	'\****************************************************************************************/

	'#define CV_POLY_APPROX_DP 0
	public const  CV_POLY_APPROX_DP as integer =  0

	'/* Approximates a single polygonal curve (contour) or
	'   a tree of polygonal curves (contours) */
	'CVAPI(CvSeq*)  cvApproxPoly( const void* src_seq,
	'                             int header_size, CvMemStorage* storage,
	'                             int method, double parameter,
	'                             int parameter2 CV_DEFAULT(0));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvApproxPoly(byval src_seq as intptr,byval header_size as integer,byref storage as CvMemStorage,byval method as integer,byval parameter as double,byval parameter2 as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvApproxPoly(byval src_seq as intptr,byval header_size as integer,byval storage as intptr,byval method as integer,byval parameter as double,byval parameter2 as integer) as IntPtr
	end function

	'#define CV_DOMINANT_IPAN 1
	public const  CV_DOMINANT_IPAN as integer =  1

	'/* Finds high-curvature points of the contour */
	'CVAPI(CvSeq*) cvFindDominantPoints( CvSeq* contour, CvMemStorage* storage,
	'                                   int method CV_DEFAULT(CV_DOMINANT_IPAN),
	'                                   double parameter1 CV_DEFAULT(0),
	'                                   double parameter2 CV_DEFAULT(0),
	'                                   double parameter3 CV_DEFAULT(0),
	'                                   double parameter4 CV_DEFAULT(0));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvFindDominantPoints(byref contour as CvSeq,byref storage as CvMemStorage,byval method as integer,byval parameter1 as double,byval parameter2 as double,byval parameter3 as double,byval parameter4 as double) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvFindDominantPoints(byval contour as intptr,byref storage as CvMemStorage,byval method as integer,byval parameter1 as double,byval parameter2 as double,byval parameter3 as double,byval parameter4 as double) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvFindDominantPoints(byref contour as CvSeq,byval storage as intptr,byval method as integer,byval parameter1 as double,byval parameter2 as double,byval parameter3 as double,byval parameter4 as double) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvFindDominantPoints(byval contour as intptr,byval storage as intptr,byval method as integer,byval parameter1 as double,byval parameter2 as double,byval parameter3 as double,byval parameter4 as double) as IntPtr
	end function

	'/* Calculates perimeter of a contour or length of a part of contour */
	'CVAPI(double)  cvArcLength( const void* curve,
	'                            CvSlice slice CV_DEFAULT(CV_WHOLE_SEQ),
	'                            int is_closed CV_DEFAULT(-1));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvArcLength(byval curve as intptr,byval slice as CvSlice,byval is_closed as integer) as double
	end function
	'#define cvContourPerimeter( contour ) cvArcLength( contour, CV_WHOLE_SEQ, 1 )
    Public Function cvContourPerimeter(ByVal contour As IntPtr) As Double
        Return cvArcLength(contour, CxTypes.CV_WHOLE_SEQ, 1)
    End Function



	'/* Calculates contour boundning rectangle (update=1) or
	'   just retrieves pre-calculated rectangle (update=0) */
	'CVAPI(CvRect)  cvBoundingRect( CvArr* points, int update CV_DEFAULT(0) );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvBoundingRect(byval points as intptr,byval update as integer) as CvRect
	end function

	'/* Calculates area of a contour or contour segment */
	'CVAPI(double)  cvContourArea( const CvArr* contour,
	'                              CvSlice slice CV_DEFAULT(CV_WHOLE_SEQ));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvContourArea(byval contour as intptr,byval slice as CvSlice) as double
	end function

	'/* Finds minimum area rotated rectangle bounding a set of points */
	'CVAPI(CvBox2D)  cvMinAreaRect2( const CvArr* points,
	'                                CvMemStorage* storage CV_DEFAULT(NULL));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMinAreaRect2(byval points as intptr,byref storage as CvMemStorage) as CvBox2D
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMinAreaRect2(byval points as intptr,byval storage as intptr) as CvBox2D
	end function

	'/* Finds minimum enclosing circle for a set of points */
	'CVAPI(int)  cvMinEnclosingCircle( const CvArr* points,
	'                                  CvPoint2D32f* center, float* radius );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMinEnclosingCircle(byval points as intptr,byref center as CvPoint2D32f,byval radius as single()) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMinEnclosingCircle(byval points as intptr,byval center as intptr,byval radius as single()) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMinEnclosingCircle(byval points as intptr,byref center as CvPoint2D32f,byref radius as single) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMinEnclosingCircle(byval points as intptr,byval center as intptr,byref radius as single) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMinEnclosingCircle(byval points as intptr,byref center as CvPoint2D32f,byval radius as intptr) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMinEnclosingCircle(byval points as intptr,byval center as intptr,byval radius as intptr) as integer
	end function

	'#define CV_CONTOURS_MATCH_I1  1
	public const  CV_CONTOURS_MATCH_I1 as integer =  1
	'#define CV_CONTOURS_MATCH_I2  2
	public const  CV_CONTOURS_MATCH_I2 as integer =  2
	'#define CV_CONTOURS_MATCH_I3  3
	public const  CV_CONTOURS_MATCH_I3 as integer =  3

	'/* Compares two contours by matching their moments */
	'CVAPI(double)  cvMatchShapes( const void* object1, const void* object2,
	'                              int method, double parameter CV_DEFAULT(0));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMatchShapes(byval object1 as intptr,byval object2 as intptr,byval method as integer,byval parameter as double) as double
	end function

	'/* Builds hierarhical representation of a contour */
	'CVAPI(CvContourTree*)  cvCreateContourTree( const CvSeq* contour,
	'                                            CvMemStorage* storage,
	'                                            double threshold );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvCreateContourTree(byref contour as CvSeq,byref storage as CvMemStorage,byval threshold as double) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvCreateContourTree(byval contour as intptr,byref storage as CvMemStorage,byval threshold as double) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvCreateContourTree(byref contour as CvSeq,byval storage as intptr,byval threshold as double) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvCreateContourTree(byval contour as intptr,byval storage as intptr,byval threshold as double) as IntPtr
	end function

	'/* Reconstruct (completelly or partially) contour a from contour tree */
	'CVAPI(CvSeq*)  cvContourFromContourTree( const CvContourTree* tree,
	'                                         CvMemStorage* storage,
	'                                         CvTermCriteria criteria );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvContourFromContourTree(byref tree as CvContourTree,byref storage as CvMemStorage,byval criteria as CvTermCriteria) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvContourFromContourTree(byval tree as intptr,byref storage as CvMemStorage,byval criteria as CvTermCriteria) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvContourFromContourTree(byref tree as CvContourTree,byval storage as intptr,byval criteria as CvTermCriteria) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvContourFromContourTree(byval tree as intptr,byval storage as intptr,byval criteria as CvTermCriteria) as IntPtr
	end function

	'/* Compares two contour trees */
	'#define  CV_CONTOUR_TREES_MATCH_I1  1
	public const  CV_CONTOUR_TREES_MATCH_I1 as integer =  1

	'CVAPI(double)  cvMatchContourTrees( const CvContourTree* tree1,
	'                                    const CvContourTree* tree2,
	'                                    int method, double threshold );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMatchContourTrees(byref tree1 as CvContourTree,byref tree2 as CvContourTree,byval method as integer,byval threshold as double) as double
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMatchContourTrees(byval tree1 as intptr,byref tree2 as CvContourTree,byval method as integer,byval threshold as double) as double
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMatchContourTrees(byref tree1 as CvContourTree,byval tree2 as intptr,byval method as integer,byval threshold as double) as double
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMatchContourTrees(byval tree1 as intptr,byval tree2 as intptr,byval method as integer,byval threshold as double) as double
	end function

	'/* Calculates histogram of a contour */
	'CVAPI(void)  cvCalcPGH( const CvSeq* contour, CvHistogram* hist );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcPGH(byref contour as CvSeq,byref hist as CvHistogram)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcPGH(byval contour as intptr,byref hist as CvHistogram)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcPGH(byref contour as CvSeq,byval hist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcPGH(byval contour as intptr,byval hist as intptr)
	end sub

	'#define CV_CLOCKWISE         1
	public const  CV_CLOCKWISE as integer =  1
	'#define CV_COUNTER_CLOCKWISE 2
	public const  CV_COUNTER_CLOCKWISE as integer =  2

	'/* Calculates exact convex hull of 2d point set */
	'CVAPI(CvSeq*) cvConvexHull2( const CvArr* input,
	'                             void* hull_storage CV_DEFAULT(NULL),
	'                             int orientation CV_DEFAULT(CV_CLOCKWISE),
	'                             int return_points CV_DEFAULT(0));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvConvexHull2(byval input as intptr,byval hull_storage as intptr,byval orientation as integer,byval return_points as integer) as IntPtr
	end function

	'/* Checks whether the contour is convex or not (returns 1 if convex, 0 if not) */
	'CVAPI(int)  cvCheckContourConvexity( const CvArr* contour );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvCheckContourConvexity(byval contour as intptr) as integer
	end function

	'/* Finds convexity defects for the contour */
	'CVAPI(CvSeq*)  cvConvexityDefects( const CvArr* contour, const CvArr* convexhull,
	'                                   CvMemStorage* storage CV_DEFAULT(NULL));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvConvexityDefects(byval contour as intptr,byval convexhull as intptr,byref storage as CvMemStorage) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvConvexityDefects(byval contour as intptr,byval convexhull as intptr,byval storage as intptr) as IntPtr
	end function

	'/* Fits ellipse into a set of 2d points */
	'CVAPI(CvBox2D) cvFitEllipse2( const CvArr* points );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvFitEllipse2(byval points as intptr) as CvBox2D
	end function

	'/* Finds minimum rectangle containing two given rectangles */
	'CVAPI(CvRect)  cvMaxRect( const CvRect* rect1, const CvRect* rect2 );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMaxRect(byref rect1 as CvRect,byref rect2 as CvRect) as CvRect
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMaxRect(byval rect1 as intptr,byref rect2 as CvRect) as CvRect
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMaxRect(byref rect1 as CvRect,byval rect2 as intptr) as CvRect
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMaxRect(byval rect1 as intptr,byval rect2 as intptr) as CvRect
	end function

	'/* Finds coordinates of the box vertices */
	'CVAPI(void) cvBoxPoints( CvBox2D box, CvPoint2D32f pt[4] );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvBoxPoints(byval box as CvBox2D,byval pt as CvPoint2D32f)
	end sub

	'/* Initializes sequence header for a matrix (column or row vector) of points -
	'   a wrapper for cvMakeSeqHeaderForArray (it does not initialize bounding rectangle!!!) */
	'CVAPI(CvSeq*) cvPointSeqFromMat( int seq_kind, const CvArr* mat,
	'                                 CvContour* contour_header,
	'                                 CvSeqBlock* block );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvPointSeqFromMat(byval seq_kind as integer,byval mat as intptr,byref contour_header as CvContour,byref block as CvSeqBlock) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvPointSeqFromMat(byval seq_kind as integer,byval mat as intptr,byval contour_header as intptr,byref block as CvSeqBlock) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvPointSeqFromMat(byval seq_kind as integer,byval mat as intptr,byref contour_header as CvContour,byval block as intptr) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvPointSeqFromMat(byval seq_kind as integer,byval mat as intptr,byval contour_header as intptr,byval block as intptr) as IntPtr
	end function

	'/* Checks whether the point is inside polygon, outside, on an edge (at a vertex).
	'   Returns positive, negative or zero value, correspondingly.
	'   Optionally, measures a signed distance between
	'   the point and the nearest polygon edge (measure_dist=1) */
	'CVAPI(double) cvPointPolygonTest( const CvArr* contour,
	'                                  CvPoint2D32f pt, int measure_dist );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvPointPolygonTest(byval contour as intptr,byval pt as CvPoint2D32f,byval measure_dist as integer) as double
	end function

	'/****************************************************************************************\
	'*                                  Histogram functions                                   *
	'\****************************************************************************************/

	'/* Creates new histogram */
	'CVAPI(CvHistogram*)  cvCreateHist( int dims, int* sizes, int type,
	'                                   float** ranges CV_DEFAULT(NULL),
	'                                   int uniform CV_DEFAULT(1));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvCreateHist(byval dims as integer,byval sizes as integer(),byval type as integer,byval ranges as intptr,byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvCreateHist(byval dims as integer,byref sizes as integer,byval type as integer,byval ranges as intptr,byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvCreateHist(byval dims as integer,byval sizes as intptr,byval type as integer,byval ranges as intptr,byval uniform as integer) as IntPtr
	end function

	'/* Assignes histogram bin ranges */
	'CVAPI(void)  cvSetHistBinRanges( CvHistogram* hist, float** ranges,
	'                                int uniform CV_DEFAULT(1));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSetHistBinRanges(byref hist as CvHistogram,byval ranges as intptr(),byval uniform as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSetHistBinRanges(byval hist as intptr,byval ranges as intptr(),byval uniform as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSetHistBinRanges(byref hist as CvHistogram,byval ranges as intptr,byval uniform as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSetHistBinRanges(byval hist as intptr,byval ranges as intptr,byval uniform as integer)
	end sub

	'/* Creates histogram header for array */
	'CVAPI(CvHistogram*)  cvMakeHistHeaderForArray(
	'                            int  dims, int* sizes, CvHistogram* hist,
	'                            float* data, float** ranges CV_DEFAULT(NULL),
	'                            int uniform CV_DEFAULT(1));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byval sizes as integer(),byref hist as CvHistogram,byval data as single(),byval ranges as intptr(),byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byref sizes as integer,byref hist as CvHistogram,byval data as single(),byval ranges as intptr(),byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byval sizes as intptr,byref hist as CvHistogram,byval data as single(),byval ranges as intptr(),byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byval sizes as integer(),byval hist as intptr,byval data as single(),byval ranges as intptr(),byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byref sizes as integer,byval hist as intptr,byval data as single(),byval ranges as intptr(),byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byval sizes as intptr,byval hist as intptr,byval data as single(),byval ranges as intptr(),byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byval sizes as integer(),byref hist as CvHistogram,byref data as single,byval ranges as intptr(),byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byref sizes as integer,byref hist as CvHistogram,byref data as single,byval ranges as intptr(),byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byval sizes as intptr,byref hist as CvHistogram,byref data as single,byval ranges as intptr(),byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byval sizes as integer(),byval hist as intptr,byref data as single,byval ranges as intptr(),byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byref sizes as integer,byval hist as intptr,byref data as single,byval ranges as intptr(),byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byval sizes as intptr,byval hist as intptr,byref data as single,byval ranges as intptr(),byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byval sizes as integer(),byref hist as CvHistogram,byval data as intptr,byval ranges as intptr(),byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byref sizes as integer,byref hist as CvHistogram,byval data as intptr,byval ranges as intptr(),byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byval sizes as intptr,byref hist as CvHistogram,byval data as intptr,byval ranges as intptr(),byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byval sizes as integer(),byval hist as intptr,byval data as intptr,byval ranges as intptr(),byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byref sizes as integer,byval hist as intptr,byval data as intptr,byval ranges as intptr(),byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byval sizes as intptr,byval hist as intptr,byval data as intptr,byval ranges as intptr(),byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byval sizes as integer(),byref hist as CvHistogram,byval data as single(),byval ranges as intptr,byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byref sizes as integer,byref hist as CvHistogram,byval data as single(),byval ranges as intptr,byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byval sizes as intptr,byref hist as CvHistogram,byval data as single(),byval ranges as intptr,byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byval sizes as integer(),byval hist as intptr,byval data as single(),byval ranges as intptr,byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byref sizes as integer,byval hist as intptr,byval data as single(),byval ranges as intptr,byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byval sizes as intptr,byval hist as intptr,byval data as single(),byval ranges as intptr,byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byval sizes as integer(),byref hist as CvHistogram,byref data as single,byval ranges as intptr,byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byref sizes as integer,byref hist as CvHistogram,byref data as single,byval ranges as intptr,byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byval sizes as intptr,byref hist as CvHistogram,byref data as single,byval ranges as intptr,byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byval sizes as integer(),byval hist as intptr,byref data as single,byval ranges as intptr,byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byref sizes as integer,byval hist as intptr,byref data as single,byval ranges as intptr,byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byval sizes as intptr,byval hist as intptr,byref data as single,byval ranges as intptr,byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byval sizes as integer(),byref hist as CvHistogram,byval data as intptr,byval ranges as intptr,byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byref sizes as integer,byref hist as CvHistogram,byval data as intptr,byval ranges as intptr,byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byval sizes as intptr,byref hist as CvHistogram,byval data as intptr,byval ranges as intptr,byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byval sizes as integer(),byval hist as intptr,byval data as intptr,byval ranges as intptr,byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byref sizes as integer,byval hist as intptr,byval data as intptr,byval ranges as intptr,byval uniform as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvMakeHistHeaderForArray(byval dims as integer,byval sizes as intptr,byval hist as intptr,byval data as intptr,byval ranges as intptr,byval uniform as integer) as IntPtr
	end function

	'/* Releases histogram */
	'CVAPI(void)  cvReleaseHist( CvHistogram** hist );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvReleaseHist(byref hist as CvHistogram)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvReleaseHist(byval hist as intptr)
	end sub

	'/* Clears all the histogram bins */
	'CVAPI(void)  cvClearHist( CvHistogram* hist );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvClearHist(byref hist as CvHistogram)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvClearHist(byval hist as intptr)
	end sub

	'/* Finds indices and values of minimum and maximum histogram bins */
	'CVAPI(void)  cvGetMinMaxHistValue( const CvHistogram* hist,
	'                                   float* min_value, float* max_value,
	'                                   int* min_idx CV_DEFAULT(NULL),
	'                                   int* max_idx CV_DEFAULT(NULL));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as single(),byval max_value as single(),byval min_idx as integer(),byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as single(),byval max_value as single(),byval min_idx as integer(),byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byref min_value as single,byval max_value as single(),byval min_idx as integer(),byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byref min_value as single,byval max_value as single(),byval min_idx as integer(),byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as intptr,byval max_value as single(),byval min_idx as integer(),byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as intptr,byval max_value as single(),byval min_idx as integer(),byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as single(),byref max_value as single,byval min_idx as integer(),byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as single(),byref max_value as single,byval min_idx as integer(),byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byref min_value as single,byref max_value as single,byval min_idx as integer(),byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byref min_value as single,byref max_value as single,byval min_idx as integer(),byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as intptr,byref max_value as single,byval min_idx as integer(),byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as intptr,byref max_value as single,byval min_idx as integer(),byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as single(),byval max_value as intptr,byval min_idx as integer(),byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as single(),byval max_value as intptr,byval min_idx as integer(),byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byref min_value as single,byval max_value as intptr,byval min_idx as integer(),byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byref min_value as single,byval max_value as intptr,byval min_idx as integer(),byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as intptr,byval max_value as intptr,byval min_idx as integer(),byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as intptr,byval max_value as intptr,byval min_idx as integer(),byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as single(),byval max_value as single(),byref min_idx as integer,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as single(),byval max_value as single(),byref min_idx as integer,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byref min_value as single,byval max_value as single(),byref min_idx as integer,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byref min_value as single,byval max_value as single(),byref min_idx as integer,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as intptr,byval max_value as single(),byref min_idx as integer,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as intptr,byval max_value as single(),byref min_idx as integer,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as single(),byref max_value as single,byref min_idx as integer,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as single(),byref max_value as single,byref min_idx as integer,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byref min_value as single,byref max_value as single,byref min_idx as integer,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byref min_value as single,byref max_value as single,byref min_idx as integer,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as intptr,byref max_value as single,byref min_idx as integer,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as intptr,byref max_value as single,byref min_idx as integer,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as single(),byval max_value as intptr,byref min_idx as integer,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as single(),byval max_value as intptr,byref min_idx as integer,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byref min_value as single,byval max_value as intptr,byref min_idx as integer,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byref min_value as single,byval max_value as intptr,byref min_idx as integer,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as intptr,byval max_value as intptr,byref min_idx as integer,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as intptr,byval max_value as intptr,byref min_idx as integer,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as single(),byval max_value as single(),byval min_idx as intptr,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as single(),byval max_value as single(),byval min_idx as intptr,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byref min_value as single,byval max_value as single(),byval min_idx as intptr,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byref min_value as single,byval max_value as single(),byval min_idx as intptr,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as intptr,byval max_value as single(),byval min_idx as intptr,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as intptr,byval max_value as single(),byval min_idx as intptr,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as single(),byref max_value as single,byval min_idx as intptr,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as single(),byref max_value as single,byval min_idx as intptr,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byref min_value as single,byref max_value as single,byval min_idx as intptr,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byref min_value as single,byref max_value as single,byval min_idx as intptr,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as intptr,byref max_value as single,byval min_idx as intptr,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as intptr,byref max_value as single,byval min_idx as intptr,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as single(),byval max_value as intptr,byval min_idx as intptr,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as single(),byval max_value as intptr,byval min_idx as intptr,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byref min_value as single,byval max_value as intptr,byval min_idx as intptr,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byref min_value as single,byval max_value as intptr,byval min_idx as intptr,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as intptr,byval max_value as intptr,byval min_idx as intptr,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as intptr,byval max_value as intptr,byval min_idx as intptr,byval max_idx as integer())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as single(),byval max_value as single(),byval min_idx as integer(),byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as single(),byval max_value as single(),byval min_idx as integer(),byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byref min_value as single,byval max_value as single(),byval min_idx as integer(),byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byref min_value as single,byval max_value as single(),byval min_idx as integer(),byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as intptr,byval max_value as single(),byval min_idx as integer(),byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as intptr,byval max_value as single(),byval min_idx as integer(),byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as single(),byref max_value as single,byval min_idx as integer(),byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as single(),byref max_value as single,byval min_idx as integer(),byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byref min_value as single,byref max_value as single,byval min_idx as integer(),byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byref min_value as single,byref max_value as single,byval min_idx as integer(),byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as intptr,byref max_value as single,byval min_idx as integer(),byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as intptr,byref max_value as single,byval min_idx as integer(),byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as single(),byval max_value as intptr,byval min_idx as integer(),byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as single(),byval max_value as intptr,byval min_idx as integer(),byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byref min_value as single,byval max_value as intptr,byval min_idx as integer(),byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byref min_value as single,byval max_value as intptr,byval min_idx as integer(),byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as intptr,byval max_value as intptr,byval min_idx as integer(),byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as intptr,byval max_value as intptr,byval min_idx as integer(),byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as single(),byval max_value as single(),byref min_idx as integer,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as single(),byval max_value as single(),byref min_idx as integer,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byref min_value as single,byval max_value as single(),byref min_idx as integer,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byref min_value as single,byval max_value as single(),byref min_idx as integer,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as intptr,byval max_value as single(),byref min_idx as integer,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as intptr,byval max_value as single(),byref min_idx as integer,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as single(),byref max_value as single,byref min_idx as integer,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as single(),byref max_value as single,byref min_idx as integer,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byref min_value as single,byref max_value as single,byref min_idx as integer,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byref min_value as single,byref max_value as single,byref min_idx as integer,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as intptr,byref max_value as single,byref min_idx as integer,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as intptr,byref max_value as single,byref min_idx as integer,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as single(),byval max_value as intptr,byref min_idx as integer,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as single(),byval max_value as intptr,byref min_idx as integer,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byref min_value as single,byval max_value as intptr,byref min_idx as integer,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byref min_value as single,byval max_value as intptr,byref min_idx as integer,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as intptr,byval max_value as intptr,byref min_idx as integer,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as intptr,byval max_value as intptr,byref min_idx as integer,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as single(),byval max_value as single(),byval min_idx as intptr,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as single(),byval max_value as single(),byval min_idx as intptr,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byref min_value as single,byval max_value as single(),byval min_idx as intptr,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byref min_value as single,byval max_value as single(),byval min_idx as intptr,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as intptr,byval max_value as single(),byval min_idx as intptr,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as intptr,byval max_value as single(),byval min_idx as intptr,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as single(),byref max_value as single,byval min_idx as intptr,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as single(),byref max_value as single,byval min_idx as intptr,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byref min_value as single,byref max_value as single,byval min_idx as intptr,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byref min_value as single,byref max_value as single,byval min_idx as intptr,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as intptr,byref max_value as single,byval min_idx as intptr,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as intptr,byref max_value as single,byval min_idx as intptr,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as single(),byval max_value as intptr,byval min_idx as intptr,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as single(),byval max_value as intptr,byval min_idx as intptr,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byref min_value as single,byval max_value as intptr,byval min_idx as intptr,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byref min_value as single,byval max_value as intptr,byval min_idx as intptr,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as intptr,byval max_value as intptr,byval min_idx as intptr,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as intptr,byval max_value as intptr,byval min_idx as intptr,byref max_idx as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as single(),byval max_value as single(),byval min_idx as integer(),byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as single(),byval max_value as single(),byval min_idx as integer(),byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byref min_value as single,byval max_value as single(),byval min_idx as integer(),byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byref min_value as single,byval max_value as single(),byval min_idx as integer(),byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as intptr,byval max_value as single(),byval min_idx as integer(),byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as intptr,byval max_value as single(),byval min_idx as integer(),byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as single(),byref max_value as single,byval min_idx as integer(),byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as single(),byref max_value as single,byval min_idx as integer(),byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byref min_value as single,byref max_value as single,byval min_idx as integer(),byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byref min_value as single,byref max_value as single,byval min_idx as integer(),byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as intptr,byref max_value as single,byval min_idx as integer(),byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as intptr,byref max_value as single,byval min_idx as integer(),byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as single(),byval max_value as intptr,byval min_idx as integer(),byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as single(),byval max_value as intptr,byval min_idx as integer(),byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byref min_value as single,byval max_value as intptr,byval min_idx as integer(),byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byref min_value as single,byval max_value as intptr,byval min_idx as integer(),byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as intptr,byval max_value as intptr,byval min_idx as integer(),byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as intptr,byval max_value as intptr,byval min_idx as integer(),byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as single(),byval max_value as single(),byref min_idx as integer,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as single(),byval max_value as single(),byref min_idx as integer,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byref min_value as single,byval max_value as single(),byref min_idx as integer,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byref min_value as single,byval max_value as single(),byref min_idx as integer,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as intptr,byval max_value as single(),byref min_idx as integer,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as intptr,byval max_value as single(),byref min_idx as integer,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as single(),byref max_value as single,byref min_idx as integer,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as single(),byref max_value as single,byref min_idx as integer,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byref min_value as single,byref max_value as single,byref min_idx as integer,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byref min_value as single,byref max_value as single,byref min_idx as integer,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as intptr,byref max_value as single,byref min_idx as integer,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as intptr,byref max_value as single,byref min_idx as integer,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as single(),byval max_value as intptr,byref min_idx as integer,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as single(),byval max_value as intptr,byref min_idx as integer,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byref min_value as single,byval max_value as intptr,byref min_idx as integer,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byref min_value as single,byval max_value as intptr,byref min_idx as integer,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as intptr,byval max_value as intptr,byref min_idx as integer,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as intptr,byval max_value as intptr,byref min_idx as integer,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as single(),byval max_value as single(),byval min_idx as intptr,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as single(),byval max_value as single(),byval min_idx as intptr,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byref min_value as single,byval max_value as single(),byval min_idx as intptr,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byref min_value as single,byval max_value as single(),byval min_idx as intptr,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as intptr,byval max_value as single(),byval min_idx as intptr,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as intptr,byval max_value as single(),byval min_idx as intptr,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as single(),byref max_value as single,byval min_idx as intptr,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as single(),byref max_value as single,byval min_idx as intptr,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byref min_value as single,byref max_value as single,byval min_idx as intptr,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byref min_value as single,byref max_value as single,byval min_idx as intptr,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as intptr,byref max_value as single,byval min_idx as intptr,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as intptr,byref max_value as single,byval min_idx as intptr,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as single(),byval max_value as intptr,byval min_idx as intptr,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as single(),byval max_value as intptr,byval min_idx as intptr,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byref min_value as single,byval max_value as intptr,byval min_idx as intptr,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byref min_value as single,byval max_value as intptr,byval min_idx as intptr,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byref hist as CvHistogram,byval min_value as intptr,byval max_value as intptr,byval min_idx as intptr,byval max_idx as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGetMinMaxHistValue(byval hist as intptr,byval min_value as intptr,byval max_value as intptr,byval min_idx as intptr,byval max_idx as intptr)
	end sub


	'/* Normalizes histogram by dividing all bins by sum of the bins, multiplied by <factor>.
	'   After that sum of histogram bins is equal to <factor> */
	'CVAPI(void)  cvNormalizeHist( CvHistogram* hist, double factor );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvNormalizeHist(byref hist as CvHistogram,byval factor as double)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvNormalizeHist(byval hist as intptr,byval factor as double)
	end sub


	'/* Clear all histogram bins that are below the threshold */
	'CVAPI(void)  cvThreshHist( CvHistogram* hist, double threshold );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvThreshHist(byref hist as CvHistogram,byval threshold as double)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvThreshHist(byval hist as intptr,byval threshold as double)
	end sub

	'#define CV_COMP_CORREL        0
	public const  CV_COMP_CORREL as integer =  0
	'#define CV_COMP_CHISQR        1
	public const  CV_COMP_CHISQR as integer =  1
	'#define CV_COMP_INTERSECT     2
	public const  CV_COMP_INTERSECT as integer =  2
	'#define CV_COMP_BHATTACHARYYA 3
	public const  CV_COMP_BHATTACHARYYA as integer =  3

	'/* Compares two histogram */
	'CVAPI(double)  cvCompareHist( const CvHistogram* hist1,
	'                              const CvHistogram* hist2,
	'                              int method);
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvCompareHist(byref hist1 as CvHistogram,byref hist2 as CvHistogram,byval method as integer) as double
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvCompareHist(byval hist1 as intptr,byref hist2 as CvHistogram,byval method as integer) as double
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvCompareHist(byref hist1 as CvHistogram,byval hist2 as intptr,byval method as integer) as double
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvCompareHist(byval hist1 as intptr,byval hist2 as intptr,byval method as integer) as double
	end function

	'/* Copies one histogram to another. Destination histogram is created if
	'   the destination pointer is NULL */
	'CVAPI(void)  cvCopyHist( const CvHistogram* src, CvHistogram** dst );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCopyHist(byref src as CvHistogram,byref dst as CvHistogram)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCopyHist(byval src as intptr,byref dst as CvHistogram)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCopyHist(byref src as CvHistogram,byval dst as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCopyHist(byval src as intptr,byval dst as intptr)
	end sub


	'/* Calculates bayesian probabilistic histograms
	'   (each or src and dst is an array of <number> histograms */
	'CVAPI(void)  cvCalcBayesianProb( CvHistogram** src, int number,
	'                                CvHistogram** dst);
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcBayesianProb(byref src as CvHistogram,byval number as integer,byref dst as CvHistogram)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcBayesianProb(byval src as intptr,byval number as integer,byref dst as CvHistogram)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcBayesianProb(byref src as CvHistogram,byval number as integer,byval dst as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcBayesianProb(byval src as intptr,byval number as integer,byval dst as intptr)
	end sub

	'/* Calculates array histogram */
	'CVAPI(void)  cvCalcArrHist( CvArr** arr, CvHistogram* hist,
	'                            int accumulate CV_DEFAULT(0),
	'                            const CvArr* mask CV_DEFAULT(NULL) );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcArrHist(byval arr as intptr,byref hist as CvHistogram,byval accumulate as integer,byval mask as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcArrHist(byval arr as intptr,byval hist as intptr,byval accumulate as integer,byval mask as intptr)
	end sub

	'CV_INLINE  void  cvCalcHist( IplImage** image, CvHistogram* hist,
	'                             int accumulate CV_DEFAULT(0),
	'                             const CvArr* mask CV_DEFAULT(NULL) )
	'{
	'    cvCalcArrHist( (CvArr**)image, hist, accumulate, mask );
	'}
    Public Sub cvCalcHist(ByVal Img As IntPtr, ByVal hist As IntPtr, ByVal accumulate As Integer, ByVal mask As IntPtr)
        cvCalcArrHist(Img, hist, accumulate, mask)
    End Sub



	'/* Calculates back project */
	'CVAPI(void)  cvCalcArrBackProject( CvArr** image, CvArr* dst,
	'                                   const CvHistogram* hist );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcArrBackProject(byval image as intptr,byval dst as intptr,byref hist as CvHistogram)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcArrBackProject(byval image as intptr,byval dst as intptr,byval hist as intptr)
	end sub
	'#define  cvCalcBackProject(image, dst, hist) cvCalcArrBackProject((CvArr**)image, dst, hist)
    Public Sub cvCalcBackProject(ByVal image As IntPtr, ByVal dst As IntPtr, ByVal hist As IntPtr)
        cvCalcArrBackProject(image, dst, hist)
    End Sub




	'/* Does some sort of template matching but compares histograms of
	'   template and each window location */
	'CVAPI(void)  cvCalcArrBackProjectPatch( CvArr** image, CvArr* dst, CvSize range,
	'                                        CvHistogram* hist, int method,
	'                                        double factor );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcArrBackProjectPatch(byval image as intptr,byval dst as intptr,byval range as CvSize,byref hist as CvHistogram,byval method as integer,byval factor as double)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcArrBackProjectPatch(byval image as intptr,byval dst as intptr,byval range as CvSize,byval hist as intptr,byval method as integer,byval factor as double)
	end sub
	'#define  cvCalcBackProjectPatch( image, dst, range, hist, method, factor ) \
	'     cvCalcArrBackProjectPatch( (CvArr**)image, dst, range, hist, method, factor )
	'Skip : 


	'/* calculates probabilistic density (divides one histogram by another) */
	'CVAPI(void)  cvCalcProbDensity( const CvHistogram* hist1, const CvHistogram* hist2,
	'                                CvHistogram* dst_hist, double scale CV_DEFAULT(255) );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcProbDensity(byref hist1 as CvHistogram,byref hist2 as CvHistogram,byref dst_hist as CvHistogram,byval scale as double)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcProbDensity(byval hist1 as intptr,byref hist2 as CvHistogram,byref dst_hist as CvHistogram,byval scale as double)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcProbDensity(byref hist1 as CvHistogram,byval hist2 as intptr,byref dst_hist as CvHistogram,byval scale as double)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcProbDensity(byval hist1 as intptr,byval hist2 as intptr,byref dst_hist as CvHistogram,byval scale as double)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcProbDensity(byref hist1 as CvHistogram,byref hist2 as CvHistogram,byval dst_hist as intptr,byval scale as double)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcProbDensity(byval hist1 as intptr,byref hist2 as CvHistogram,byval dst_hist as intptr,byval scale as double)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcProbDensity(byref hist1 as CvHistogram,byval hist2 as intptr,byval dst_hist as intptr,byval scale as double)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcProbDensity(byval hist1 as intptr,byval hist2 as intptr,byval dst_hist as intptr,byval scale as double)
	end sub

	'/* equalizes histogram of 8-bit single-channel image */
	'CVAPI(void)  cvEqualizeHist( const CvArr* src, CvArr* dst );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvEqualizeHist(byval src as intptr,byval dst as intptr)
	end sub


	'#define  CV_VALUE  1
	public const  CV_VALUE as integer =  1
	'#define  CV_ARRAY  2
	public const  CV_ARRAY as integer =  2
	'/* Updates active contour in order to minimize its cummulative
	'   (internal and external) energy. */
	'CVAPI(void)  cvSnakeImage( const IplImage* image, CvPoint* points,
	'                           int  length, float* alpha,
	'                           float* beta, float* gamma,
	'                           int coeff_usage, CvSize  win,
	'                           CvTermCriteria criteria, int calc_gradient CV_DEFAULT(1));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byref points as CvPoint,byval length as integer,byval alpha as single(),byval beta as single(),byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byref points as CvPoint,byval length as integer,byval alpha as single(),byval beta as single(),byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byval points as intptr,byval length as integer,byval alpha as single(),byval beta as single(),byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byval points as intptr,byval length as integer,byval alpha as single(),byval beta as single(),byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byref points as CvPoint,byval length as integer,byref alpha as single,byval beta as single(),byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byref points as CvPoint,byval length as integer,byref alpha as single,byval beta as single(),byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byval points as intptr,byval length as integer,byref alpha as single,byval beta as single(),byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byval points as intptr,byval length as integer,byref alpha as single,byval beta as single(),byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byref points as CvPoint,byval length as integer,byval alpha as intptr,byval beta as single(),byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byref points as CvPoint,byval length as integer,byval alpha as intptr,byval beta as single(),byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byval points as intptr,byval length as integer,byval alpha as intptr,byval beta as single(),byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byval points as intptr,byval length as integer,byval alpha as intptr,byval beta as single(),byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byref points as CvPoint,byval length as integer,byval alpha as single(),byref beta as single,byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byref points as CvPoint,byval length as integer,byval alpha as single(),byref beta as single,byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byval points as intptr,byval length as integer,byval alpha as single(),byref beta as single,byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byval points as intptr,byval length as integer,byval alpha as single(),byref beta as single,byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byref points as CvPoint,byval length as integer,byref alpha as single,byref beta as single,byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byref points as CvPoint,byval length as integer,byref alpha as single,byref beta as single,byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byval points as intptr,byval length as integer,byref alpha as single,byref beta as single,byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byval points as intptr,byval length as integer,byref alpha as single,byref beta as single,byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byref points as CvPoint,byval length as integer,byval alpha as intptr,byref beta as single,byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byref points as CvPoint,byval length as integer,byval alpha as intptr,byref beta as single,byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byval points as intptr,byval length as integer,byval alpha as intptr,byref beta as single,byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byval points as intptr,byval length as integer,byval alpha as intptr,byref beta as single,byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byref points as CvPoint,byval length as integer,byval alpha as single(),byval beta as intptr,byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byref points as CvPoint,byval length as integer,byval alpha as single(),byval beta as intptr,byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byval points as intptr,byval length as integer,byval alpha as single(),byval beta as intptr,byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byval points as intptr,byval length as integer,byval alpha as single(),byval beta as intptr,byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byref points as CvPoint,byval length as integer,byref alpha as single,byval beta as intptr,byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byref points as CvPoint,byval length as integer,byref alpha as single,byval beta as intptr,byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byval points as intptr,byval length as integer,byref alpha as single,byval beta as intptr,byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byval points as intptr,byval length as integer,byref alpha as single,byval beta as intptr,byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byref points as CvPoint,byval length as integer,byval alpha as intptr,byval beta as intptr,byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byref points as CvPoint,byval length as integer,byval alpha as intptr,byval beta as intptr,byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byval points as intptr,byval length as integer,byval alpha as intptr,byval beta as intptr,byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byval points as intptr,byval length as integer,byval alpha as intptr,byval beta as intptr,byval gamma as single(),byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byref points as CvPoint,byval length as integer,byval alpha as single(),byval beta as single(),byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byref points as CvPoint,byval length as integer,byval alpha as single(),byval beta as single(),byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byval points as intptr,byval length as integer,byval alpha as single(),byval beta as single(),byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byval points as intptr,byval length as integer,byval alpha as single(),byval beta as single(),byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byref points as CvPoint,byval length as integer,byref alpha as single,byval beta as single(),byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byref points as CvPoint,byval length as integer,byref alpha as single,byval beta as single(),byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byval points as intptr,byval length as integer,byref alpha as single,byval beta as single(),byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byval points as intptr,byval length as integer,byref alpha as single,byval beta as single(),byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byref points as CvPoint,byval length as integer,byval alpha as intptr,byval beta as single(),byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byref points as CvPoint,byval length as integer,byval alpha as intptr,byval beta as single(),byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byval points as intptr,byval length as integer,byval alpha as intptr,byval beta as single(),byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byval points as intptr,byval length as integer,byval alpha as intptr,byval beta as single(),byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byref points as CvPoint,byval length as integer,byval alpha as single(),byref beta as single,byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byref points as CvPoint,byval length as integer,byval alpha as single(),byref beta as single,byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byval points as intptr,byval length as integer,byval alpha as single(),byref beta as single,byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byval points as intptr,byval length as integer,byval alpha as single(),byref beta as single,byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byref points as CvPoint,byval length as integer,byref alpha as single,byref beta as single,byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byref points as CvPoint,byval length as integer,byref alpha as single,byref beta as single,byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byval points as intptr,byval length as integer,byref alpha as single,byref beta as single,byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byval points as intptr,byval length as integer,byref alpha as single,byref beta as single,byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byref points as CvPoint,byval length as integer,byval alpha as intptr,byref beta as single,byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byref points as CvPoint,byval length as integer,byval alpha as intptr,byref beta as single,byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byval points as intptr,byval length as integer,byval alpha as intptr,byref beta as single,byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byval points as intptr,byval length as integer,byval alpha as intptr,byref beta as single,byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byref points as CvPoint,byval length as integer,byval alpha as single(),byval beta as intptr,byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byref points as CvPoint,byval length as integer,byval alpha as single(),byval beta as intptr,byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byval points as intptr,byval length as integer,byval alpha as single(),byval beta as intptr,byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byval points as intptr,byval length as integer,byval alpha as single(),byval beta as intptr,byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byref points as CvPoint,byval length as integer,byref alpha as single,byval beta as intptr,byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byref points as CvPoint,byval length as integer,byref alpha as single,byval beta as intptr,byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byval points as intptr,byval length as integer,byref alpha as single,byval beta as intptr,byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byval points as intptr,byval length as integer,byref alpha as single,byval beta as intptr,byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byref points as CvPoint,byval length as integer,byval alpha as intptr,byval beta as intptr,byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byref points as CvPoint,byval length as integer,byval alpha as intptr,byval beta as intptr,byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byval points as intptr,byval length as integer,byval alpha as intptr,byval beta as intptr,byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byval points as intptr,byval length as integer,byval alpha as intptr,byval beta as intptr,byref gamma as single,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byref points as CvPoint,byval length as integer,byval alpha as single(),byval beta as single(),byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byref points as CvPoint,byval length as integer,byval alpha as single(),byval beta as single(),byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byval points as intptr,byval length as integer,byval alpha as single(),byval beta as single(),byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byval points as intptr,byval length as integer,byval alpha as single(),byval beta as single(),byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byref points as CvPoint,byval length as integer,byref alpha as single,byval beta as single(),byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byref points as CvPoint,byval length as integer,byref alpha as single,byval beta as single(),byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byval points as intptr,byval length as integer,byref alpha as single,byval beta as single(),byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byval points as intptr,byval length as integer,byref alpha as single,byval beta as single(),byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byref points as CvPoint,byval length as integer,byval alpha as intptr,byval beta as single(),byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byref points as CvPoint,byval length as integer,byval alpha as intptr,byval beta as single(),byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byval points as intptr,byval length as integer,byval alpha as intptr,byval beta as single(),byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byval points as intptr,byval length as integer,byval alpha as intptr,byval beta as single(),byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byref points as CvPoint,byval length as integer,byval alpha as single(),byref beta as single,byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byref points as CvPoint,byval length as integer,byval alpha as single(),byref beta as single,byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byval points as intptr,byval length as integer,byval alpha as single(),byref beta as single,byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byval points as intptr,byval length as integer,byval alpha as single(),byref beta as single,byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byref points as CvPoint,byval length as integer,byref alpha as single,byref beta as single,byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byref points as CvPoint,byval length as integer,byref alpha as single,byref beta as single,byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byval points as intptr,byval length as integer,byref alpha as single,byref beta as single,byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byval points as intptr,byval length as integer,byref alpha as single,byref beta as single,byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byref points as CvPoint,byval length as integer,byval alpha as intptr,byref beta as single,byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byref points as CvPoint,byval length as integer,byval alpha as intptr,byref beta as single,byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byval points as intptr,byval length as integer,byval alpha as intptr,byref beta as single,byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byval points as intptr,byval length as integer,byval alpha as intptr,byref beta as single,byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byref points as CvPoint,byval length as integer,byval alpha as single(),byval beta as intptr,byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byref points as CvPoint,byval length as integer,byval alpha as single(),byval beta as intptr,byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byval points as intptr,byval length as integer,byval alpha as single(),byval beta as intptr,byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byval points as intptr,byval length as integer,byval alpha as single(),byval beta as intptr,byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byref points as CvPoint,byval length as integer,byref alpha as single,byval beta as intptr,byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byref points as CvPoint,byval length as integer,byref alpha as single,byval beta as intptr,byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byval points as intptr,byval length as integer,byref alpha as single,byval beta as intptr,byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byval points as intptr,byval length as integer,byref alpha as single,byval beta as intptr,byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byref points as CvPoint,byval length as integer,byval alpha as intptr,byval beta as intptr,byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byref points as CvPoint,byval length as integer,byval alpha as intptr,byval beta as intptr,byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byref image as IplImage,byval points as intptr,byval length as integer,byval alpha as intptr,byval beta as intptr,byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSnakeImage(byval image as intptr,byval points as intptr,byval length as integer,byval alpha as intptr,byval beta as intptr,byval gamma as intptr,byval coeff_usage as integer,byval win as CvSize,byval criteria as CvTermCriteria,byval calc_gradient as integer)
	end sub

	'/* Calculates the cooficients of the homography matrix */
	'CVAPI(void)  cvCalcImageHomography( float* line, CvPoint3D32f* center,
	'                                    float* intrinsic, float* homography );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as single(),byref center as CvPoint3D32f,byval intrinsic as single(),byval homography as single())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byref line as single,byref center as CvPoint3D32f,byval intrinsic as single(),byval homography as single())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as intptr,byref center as CvPoint3D32f,byval intrinsic as single(),byval homography as single())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as single(),byval center as intptr,byval intrinsic as single(),byval homography as single())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byref line as single,byval center as intptr,byval intrinsic as single(),byval homography as single())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as intptr,byval center as intptr,byval intrinsic as single(),byval homography as single())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as single(),byref center as CvPoint3D32f,byref intrinsic as single,byval homography as single())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byref line as single,byref center as CvPoint3D32f,byref intrinsic as single,byval homography as single())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as intptr,byref center as CvPoint3D32f,byref intrinsic as single,byval homography as single())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as single(),byval center as intptr,byref intrinsic as single,byval homography as single())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byref line as single,byval center as intptr,byref intrinsic as single,byval homography as single())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as intptr,byval center as intptr,byref intrinsic as single,byval homography as single())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as single(),byref center as CvPoint3D32f,byval intrinsic as intptr,byval homography as single())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byref line as single,byref center as CvPoint3D32f,byval intrinsic as intptr,byval homography as single())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as intptr,byref center as CvPoint3D32f,byval intrinsic as intptr,byval homography as single())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as single(),byval center as intptr,byval intrinsic as intptr,byval homography as single())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byref line as single,byval center as intptr,byval intrinsic as intptr,byval homography as single())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as intptr,byval center as intptr,byval intrinsic as intptr,byval homography as single())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as single(),byref center as CvPoint3D32f,byval intrinsic as single(),byref homography as single)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byref line as single,byref center as CvPoint3D32f,byval intrinsic as single(),byref homography as single)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as intptr,byref center as CvPoint3D32f,byval intrinsic as single(),byref homography as single)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as single(),byval center as intptr,byval intrinsic as single(),byref homography as single)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byref line as single,byval center as intptr,byval intrinsic as single(),byref homography as single)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as intptr,byval center as intptr,byval intrinsic as single(),byref homography as single)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as single(),byref center as CvPoint3D32f,byref intrinsic as single,byref homography as single)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byref line as single,byref center as CvPoint3D32f,byref intrinsic as single,byref homography as single)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as intptr,byref center as CvPoint3D32f,byref intrinsic as single,byref homography as single)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as single(),byval center as intptr,byref intrinsic as single,byref homography as single)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byref line as single,byval center as intptr,byref intrinsic as single,byref homography as single)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as intptr,byval center as intptr,byref intrinsic as single,byref homography as single)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as single(),byref center as CvPoint3D32f,byval intrinsic as intptr,byref homography as single)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byref line as single,byref center as CvPoint3D32f,byval intrinsic as intptr,byref homography as single)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as intptr,byref center as CvPoint3D32f,byval intrinsic as intptr,byref homography as single)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as single(),byval center as intptr,byval intrinsic as intptr,byref homography as single)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byref line as single,byval center as intptr,byval intrinsic as intptr,byref homography as single)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as intptr,byval center as intptr,byval intrinsic as intptr,byref homography as single)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as single(),byref center as CvPoint3D32f,byval intrinsic as single(),byval homography as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byref line as single,byref center as CvPoint3D32f,byval intrinsic as single(),byval homography as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as intptr,byref center as CvPoint3D32f,byval intrinsic as single(),byval homography as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as single(),byval center as intptr,byval intrinsic as single(),byval homography as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byref line as single,byval center as intptr,byval intrinsic as single(),byval homography as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as intptr,byval center as intptr,byval intrinsic as single(),byval homography as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as single(),byref center as CvPoint3D32f,byref intrinsic as single,byval homography as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byref line as single,byref center as CvPoint3D32f,byref intrinsic as single,byval homography as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as intptr,byref center as CvPoint3D32f,byref intrinsic as single,byval homography as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as single(),byval center as intptr,byref intrinsic as single,byval homography as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byref line as single,byval center as intptr,byref intrinsic as single,byval homography as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as intptr,byval center as intptr,byref intrinsic as single,byval homography as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as single(),byref center as CvPoint3D32f,byval intrinsic as intptr,byval homography as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byref line as single,byref center as CvPoint3D32f,byval intrinsic as intptr,byval homography as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as intptr,byref center as CvPoint3D32f,byval intrinsic as intptr,byval homography as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as single(),byval center as intptr,byval intrinsic as intptr,byval homography as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byref line as single,byval center as intptr,byval intrinsic as intptr,byval homography as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalcImageHomography(byval line as intptr,byval center as intptr,byval intrinsic as intptr,byval homography as intptr)
	end sub

	'#define CV_DIST_MASK_3   3
	public const  CV_DIST_MASK_3 as integer =  3
	'#define CV_DIST_MASK_5   5
	public const  CV_DIST_MASK_5 as integer =  5
	'#define CV_DIST_MASK_PRECISE 0
	public const  CV_DIST_MASK_PRECISE as integer =  0

	'/* Applies distance transform to binary image */
	'CVAPI(void)  cvDistTransform( const CvArr* src, CvArr* dst,
	'                              int distance_type CV_DEFAULT(CV_DIST_L2),
	'                              int mask_size CV_DEFAULT(3),
	'                              const float* mask CV_DEFAULT(NULL),
	'                              CvArr* labels CV_DEFAULT(NULL));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvDistTransform(byval src as intptr,byval dst as intptr,byval distance_type as integer,byval mask_size as integer,byval mask as single(),byval labels as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvDistTransform(byval src as intptr,byval dst as intptr,byval distance_type as integer,byval mask_size as integer,byref mask as single,byval labels as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvDistTransform(byval src as intptr,byval dst as intptr,byval distance_type as integer,byval mask_size as integer,byval mask as intptr,byval labels as intptr)
	end sub


	'/* Types of thresholding */
	'#define CV_THRESH_BINARY      0  /* value = value > threshold ? max_value : 0       */
	public const  CV_THRESH_BINARY as integer =  0
	'#define CV_THRESH_BINARY_INV  1  /* value = value > threshold ? 0 : max_value       */
	public const  CV_THRESH_BINARY_INV as integer =  1
	'#define CV_THRESH_TRUNC       2  /* value = value > threshold ? threshold : value   */
	public const  CV_THRESH_TRUNC as integer =  2
	'#define CV_THRESH_TOZERO      3  /* value = value > threshold ? value : 0           */
	public const  CV_THRESH_TOZERO as integer =  3
	'#define CV_THRESH_TOZERO_INV  4  /* value = value > threshold ? 0 : value           */
	public const  CV_THRESH_TOZERO_INV as integer =  4
	'#define CV_THRESH_MASK        7
	public const  CV_THRESH_MASK as integer =  7

	'#define CV_THRESH_OTSU        8  /* use Otsu algorithm to choose the optimal threshold value;
	public const  CV_THRESH_OTSU as integer =  8
	'                                    combine the flag with one of the above CV_THRESH_* values */

	'/* Applies fixed-level threshold to grayscale image.
	'   This is a basic operation applied before retrieving contours */
	'CVAPI(void)  cvThreshold( const CvArr*  src, CvArr*  dst,
	'                          double  threshold, double  max_value,
	'                          int threshold_type );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvThreshold(byval src as intptr,byval dst as intptr,byval threshold as double,byval max_value as double,byval threshold_type as integer)
	end sub

	'#define CV_ADAPTIVE_THRESH_MEAN_C  0
	public const  CV_ADAPTIVE_THRESH_MEAN_C as integer =  0
	'#define CV_ADAPTIVE_THRESH_GAUSSIAN_C  1
	public const  CV_ADAPTIVE_THRESH_GAUSSIAN_C as integer =  1

	'/* Applies adaptive threshold to grayscale image.
	'   The two parameters for methods CV_ADAPTIVE_THRESH_MEAN_C and
	'   CV_ADAPTIVE_THRESH_GAUSSIAN_C are:
	'   neighborhood size (3, 5, 7 etc.),
	'   and a constant subtracted from mean (...,-3,-2,-1,0,1,2,3,...) */
	'CVAPI(void)  cvAdaptiveThreshold( const CvArr* src, CvArr* dst, double max_value,
	'                                  int adaptive_method CV_DEFAULT(CV_ADAPTIVE_THRESH_MEAN_C),
	'                                  int threshold_type CV_DEFAULT(CV_THRESH_BINARY),
	'                                  int block_size CV_DEFAULT(3),
	'                                  double param1 CV_DEFAULT(5));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvAdaptiveThreshold(byval src as intptr,byval dst as intptr,byval max_value as double,byval adaptive_method as integer,byval threshold_type as integer,byval block_size as integer,byval param1 as double)
	end sub

	'#define CV_FLOODFILL_FIXED_RANGE (1 << 16)
	public const  CV_FLOODFILL_FIXED_RANGE as integer =  (1 << 16)
	'#define CV_FLOODFILL_MASK_ONLY   (1 << 17)
	public const  CV_FLOODFILL_MASK_ONLY as integer =  (1 << 17)

	'/* Fills the connected component until the color difference gets large enough */
	'CVAPI(void)  cvFloodFill( CvArr* image, CvPoint seed_point,
	'                          CvScalar new_val, CvScalar lo_diff CV_DEFAULT(cvScalarAll(0)),
	'                          CvScalar up_diff CV_DEFAULT(cvScalarAll(0)),
	'                          CvConnectedComp* comp CV_DEFAULT(NULL),
	'                          int flags CV_DEFAULT(4),
	'                          CvArr* mask CV_DEFAULT(NULL));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFloodFill(byval image as intptr,byval seed_point as CvPoint,byval new_val as CvScalar,byval lo_diff as CvScalar,byval up_diff as CvScalar,byref comp as CvConnectedComp,byval flags as integer,byval mask as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFloodFill(byval image as intptr,byval seed_point as CvPoint,byval new_val as CvScalar,byval lo_diff as CvScalar,byval up_diff as CvScalar,byval comp as intptr,byval flags as integer,byval mask as intptr)
	end sub

	'/****************************************************************************************\
	'*                                  Feature detection                                     *
	'\****************************************************************************************/

	'#define CV_CANNY_L2_GRADIENT  (1 << 31)
	public const  CV_CANNY_L2_GRADIENT as integer =  (1 << 31)

	'/* Runs canny edge detector */
	'CVAPI(void)  cvCanny( const CvArr* image, CvArr* edges, double threshold1,
	'                      double threshold2, int  aperture_size CV_DEFAULT(3) );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCanny(byval image as intptr,byval edges as intptr,byval threshold1 as double,byval threshold2 as double,byval aperture_size as integer)
	end sub

	'/* Calculates constraint image for corner detection
	'   Dx^2 * Dyy + Dxx * Dy^2 - 2 * Dx * Dy * Dxy.
	'   Applying threshold to the result gives coordinates of corners */
	'CVAPI(void) cvPreCornerDetect( const CvArr* image, CvArr* corners,
	'                              int aperture_size CV_DEFAULT(3) );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvPreCornerDetect(byval image as intptr,byval corners as intptr,byval aperture_size as integer)
	end sub

	'/* Calculates eigen values and vectors of 2x2
	'   gradient covariation matrix at every image pixel */
	'CVAPI(void)  cvCornerEigenValsAndVecs( const CvArr* image, CvArr* eigenvv,
	'                                      int block_size, int aperture_size CV_DEFAULT(3) );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCornerEigenValsAndVecs(byval image as intptr,byval eigenvv as intptr,byval block_size as integer,byval aperture_size as integer)
	end sub

	'/* Calculates minimal eigenvalue for 2x2 gradient covariation matrix at
	'   every image pixel */
	'CVAPI(void)  cvCornerMinEigenVal( const CvArr* image, CvArr* eigenval,
	'                                 int block_size, int aperture_size CV_DEFAULT(3) );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCornerMinEigenVal(byval image as intptr,byval eigenval as intptr,byval block_size as integer,byval aperture_size as integer)
	end sub

	'/* Harris corner detector:
	'   Calculates det(M) - k*(trace(M)^2), where M is 2x2 gradient covariation matrix for each pixel */
	'CVAPI(void)  cvCornerHarris( const CvArr* image, CvArr* harris_responce,
	'                             int block_size, int aperture_size CV_DEFAULT(3),
	'                             double k CV_DEFAULT(0.04) );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCornerHarris(byval image as intptr,byval harris_responce as intptr,byval block_size as integer,byval aperture_size as integer,byval k as double)
	end sub

	'/* Adjust corner position using some sort of gradient search */
	'CVAPI(void)  cvFindCornerSubPix( const CvArr* image, CvPoint2D32f* corners,
	'                                 int count, CvSize win, CvSize zero_zone,
	'                                 CvTermCriteria  criteria );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindCornerSubPix(byval image as intptr,byref corners as CvPoint2D32f,byval count as integer,byval win as CvSize,byval zero_zone as CvSize,byval criteria as CvTermCriteria)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindCornerSubPix(byval image as intptr,byval corners as intptr,byval count as integer,byval win as CvSize,byval zero_zone as CvSize,byval criteria as CvTermCriteria)
	end sub

	'/* Finds a sparse set of points within the selected region
	'   that seem to be easy to track */
	'CVAPI(void)  cvGoodFeaturesToTrack( const CvArr* image, CvArr* eig_image,
	'                                   CvArr* temp_image, CvPoint2D32f* corners,
	'                                   int* corner_count, double  quality_level,
	'                                   double  min_distance,
	'                                   const CvArr* mask CV_DEFAULT(NULL),
	'                                   int block_size CV_DEFAULT(3),
	'                                   int use_harris CV_DEFAULT(0),
	'                                   double k CV_DEFAULT(0.04) );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGoodFeaturesToTrack(byval image as intptr,byval eig_image as intptr,byval temp_image as intptr,byref corners as CvPoint2D32f,byval corner_count as integer(),byval quality_level as double,byval min_distance as double,byval mask as intptr,byval block_size as integer,byval use_harris as integer,byval k as double)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGoodFeaturesToTrack(byval image as intptr,byval eig_image as intptr,byval temp_image as intptr,byval corners as intptr,byval corner_count as integer(),byval quality_level as double,byval min_distance as double,byval mask as intptr,byval block_size as integer,byval use_harris as integer,byval k as double)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGoodFeaturesToTrack(byval image as intptr,byval eig_image as intptr,byval temp_image as intptr,byref corners as CvPoint2D32f,byref corner_count as integer,byval quality_level as double,byval min_distance as double,byval mask as intptr,byval block_size as integer,byval use_harris as integer,byval k as double)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGoodFeaturesToTrack(byval image as intptr,byval eig_image as intptr,byval temp_image as intptr,byval corners as intptr,byref corner_count as integer,byval quality_level as double,byval min_distance as double,byval mask as intptr,byval block_size as integer,byval use_harris as integer,byval k as double)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGoodFeaturesToTrack(byval image as intptr,byval eig_image as intptr,byval temp_image as intptr,byref corners as CvPoint2D32f,byval corner_count as intptr,byval quality_level as double,byval min_distance as double,byval mask as intptr,byval block_size as integer,byval use_harris as integer,byval k as double)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvGoodFeaturesToTrack(byval image as intptr,byval eig_image as intptr,byval temp_image as intptr,byval corners as intptr,byval corner_count as intptr,byval quality_level as double,byval min_distance as double,byval mask as intptr,byval block_size as integer,byval use_harris as integer,byval k as double)
	end sub

	'#define CV_HOUGH_STANDARD 0
	public const  CV_HOUGH_STANDARD as integer =  0
	'#define CV_HOUGH_PROBABILISTIC 1
	public const  CV_HOUGH_PROBABILISTIC as integer =  1
	'#define CV_HOUGH_MULTI_SCALE 2
	public const  CV_HOUGH_MULTI_SCALE as integer =  2
	'#define CV_HOUGH_GRADIENT 3
	public const  CV_HOUGH_GRADIENT as integer =  3

	'/* Finds lines on binary image using one of several methods.
	'   line_storage is either memory storage or 1 x <max number of lines> CvMat, its
	'   number of columns is changed by the function.
	'   method is one of CV_HOUGH_*;
	'   rho, theta and threshold are used for each of those methods;
	'   param1 ~ line length, param2 ~ line gap - for probabilistic,
	'   param1 ~ srn, param2 ~ stn - for multi-scale */
	'CVAPI(CvSeq*)  cvHoughLines2( CvArr* image, void* line_storage, int method, 
	'                              double rho, double theta, int threshold,
	'                              double param1 CV_DEFAULT(0), double param2 CV_DEFAULT(0));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvHoughLines2(byval image as intptr,byval line_storage as intptr,byval method as integer,byval rho as double,byval theta as double,byval threshold as integer,byval param1 as double,byval param2 as double) as IntPtr
	end function

	'/* Finds circles in the image */
	'CVAPI(CvSeq*) cvHoughCircles( CvArr* image, void* circle_storage,
	'                              int method, double dp, double min_dist,
	'                              double param1 CV_DEFAULT(100),
	'                              double param2 CV_DEFAULT(100),
	'                              int min_radius CV_DEFAULT(0),
	'                              int max_radius CV_DEFAULT(0));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvHoughCircles(byval image as intptr,byval circle_storage as intptr,byval method as integer,byval dp as double,byval min_dist as double,byval param1 as double,byval param2 as double,byval min_radius as integer,byval max_radius as integer) as IntPtr
	end function

	'/* Fits a line into set of 2d or 3d points in a robust way (M-estimator technique) */
	'CVAPI(void)  cvFitLine( const CvArr* points, int dist_type, double param,
	'                        double reps, double aeps, float* line );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFitLine(byval points as intptr,byval dist_type as integer,byval param as double,byval reps as double,byval aeps as double,byval line as single())
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFitLine(byval points as intptr,byval dist_type as integer,byval param as double,byval reps as double,byval aeps as double,byref line as single)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFitLine(byval points as intptr,byval dist_type as integer,byval param as double,byval reps as double,byval aeps as double,byval line as intptr)
	end sub

	'/****************************************************************************************\
	'*                         Haar-like Object Detection functions                           *
	'\****************************************************************************************/

	'/* Loads haar classifier cascade from a directory.
	'   It is obsolete: convert your cascade to xml and use cvLoad instead */
	'CVAPI(CvHaarClassifierCascade*) cvLoadHaarClassifierCascade(
	'                    const char* directory, CvSize orig_window_size);
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvLoadHaarClassifierCascade(byval directory as string,byval orig_window_size as CvSize) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvLoadHaarClassifierCascade(byval directory as byte(),byval orig_window_size as CvSize) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvLoadHaarClassifierCascade(byval directory as intptr,byval orig_window_size as CvSize) as IntPtr
	end function

	'CVAPI(void) cvReleaseHaarClassifierCascade( CvHaarClassifierCascade** cascade );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvReleaseHaarClassifierCascade(byref cascade as intptr)
	end sub

	'#define CV_HAAR_DO_CANNY_PRUNING 1
	public const  CV_HAAR_DO_CANNY_PRUNING as integer =  1
	'#define CV_HAAR_SCALE_IMAGE      2
	public const  CV_HAAR_SCALE_IMAGE as integer =  2

	'CVAPI(CvSeq*) cvHaarDetectObjects( const CvArr* image,
	'                     CvHaarClassifierCascade* cascade,
	'                     CvMemStorage* storage, double scale_factor CV_DEFAULT(1.1),
	'                     int min_neighbors CV_DEFAULT(3), int flags CV_DEFAULT(0),
	'                     CvSize min_size CV_DEFAULT(cvSize(0,0)));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvHaarDetectObjects(byval image as intptr,byref cascade as CvHaarClassifierCascade,byref storage as CvMemStorage,byval scale_factor as double,byval min_neighbors as integer,byval flags as integer,byval min_size as CvSize) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvHaarDetectObjects(byval image as intptr,byval cascade as intptr,byref storage as CvMemStorage,byval scale_factor as double,byval min_neighbors as integer,byval flags as integer,byval min_size as CvSize) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvHaarDetectObjects(byval image as intptr,byref cascade as CvHaarClassifierCascade,byval storage as intptr,byval scale_factor as double,byval min_neighbors as integer,byval flags as integer,byval min_size as CvSize) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvHaarDetectObjects(byval image as intptr,byval cascade as intptr,byval storage as intptr,byval scale_factor as double,byval min_neighbors as integer,byval flags as integer,byval min_size as CvSize) as IntPtr
	end function

	'/* sets images for haar classifier cascade */
	'CVAPI(void) cvSetImagesForHaarClassifierCascade( CvHaarClassifierCascade* cascade,
	'                                                const CvArr* sum, const CvArr* sqsum,
	'                                                const CvArr* tilted_sum, double scale );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSetImagesForHaarClassifierCascade(byref cascade as CvHaarClassifierCascade,byval sum as intptr,byval sqsum as intptr,byval tilted_sum as intptr,byval scale as double)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvSetImagesForHaarClassifierCascade(byval cascade as intptr,byval sum as intptr,byval sqsum as intptr,byval tilted_sum as intptr,byval scale as double)
	end sub

	'/* runs the cascade on the specified window */
	'CVAPI(int) cvRunHaarClassifierCascade( CvHaarClassifierCascade* cascade,
	'                                      CvPoint pt, int start_stage CV_DEFAULT(0));
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvRunHaarClassifierCascade(byref cascade as CvHaarClassifierCascade,byval pt as CvPoint,byval start_stage as integer) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvRunHaarClassifierCascade(byval cascade as intptr,byval pt as CvPoint,byval start_stage as integer) as integer
	end function

	'/****************************************************************************************\
	'*                     Camera Calibration and Rectification functions                     *
	'\****************************************************************************************/

	'/* transforms the input image to compensate lens distortion */
	'CVAPI(void) cvUndistort2( const CvArr* src, CvArr* dst,
	'                          const CvMat* intrinsic_matrix,
	'                          const CvMat* distortion_coeffs );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvUndistort2(byval src as intptr,byval dst as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvUndistort2(byval src as intptr,byval dst as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvUndistort2(byval src as intptr,byval dst as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvUndistort2(byval src as intptr,byval dst as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr)
	end sub

	'/* computes transformation map from intrinsic camera parameters
	'   that can used by cvRemap */
	'CVAPI(void) cvInitUndistortMap( const CvMat* intrinsic_matrix,
	'                                const CvMat* distortion_coeffs,
	'                                CvArr* mapx, CvArr* mapy );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvInitUndistortMap(byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval mapx as intptr,byval mapy as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvInitUndistortMap(byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval mapx as intptr,byval mapy as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvInitUndistortMap(byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval mapx as intptr,byval mapy as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvInitUndistortMap(byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval mapx as intptr,byval mapy as intptr)
	end sub

	'/* converts rotation vector to rotation matrix or vice versa */
	'CVAPI(int) cvRodrigues2( const CvMat* src, CvMat* dst,
	'                         CvMat* jacobian CV_DEFAULT(0) );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvRodrigues2(byref src as CvMat,byref dst as CvMat,byref jacobian as CvMat) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvRodrigues2(byval src as intptr,byref dst as CvMat,byref jacobian as CvMat) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvRodrigues2(byref src as CvMat,byval dst as intptr,byref jacobian as CvMat) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvRodrigues2(byval src as intptr,byval dst as intptr,byref jacobian as CvMat) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvRodrigues2(byref src as CvMat,byref dst as CvMat,byval jacobian as intptr) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvRodrigues2(byval src as intptr,byref dst as CvMat,byval jacobian as intptr) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvRodrigues2(byref src as CvMat,byval dst as intptr,byval jacobian as intptr) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvRodrigues2(byval src as intptr,byval dst as intptr,byval jacobian as intptr) as integer
	end function

	'/* finds perspective transformation between the object plane and image (view) plane */
	'CVAPI(void) cvFindHomography( const CvMat* src_points,
	'                              const CvMat* dst_points,
	'                              CvMat* homography );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindHomography(byref src_points as CvMat,byref dst_points as CvMat,byref homography as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindHomography(byval src_points as intptr,byref dst_points as CvMat,byref homography as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindHomography(byref src_points as CvMat,byval dst_points as intptr,byref homography as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindHomography(byval src_points as intptr,byval dst_points as intptr,byref homography as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindHomography(byref src_points as CvMat,byref dst_points as CvMat,byval homography as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindHomography(byval src_points as intptr,byref dst_points as CvMat,byval homography as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindHomography(byref src_points as CvMat,byval dst_points as intptr,byval homography as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindHomography(byval src_points as intptr,byval dst_points as intptr,byval homography as intptr)
	end sub

	'/* projects object points to the view plane using
	'   the specified extrinsic and intrinsic camera parameters */
	'CVAPI(void) cvProjectPoints2( const CvMat* object_points, const CvMat* rotation_vector,
	'                              const CvMat* translation_vector, const CvMat* intrinsic_matrix,
	'                              const CvMat* distortion_coeffs, CvMat* image_points,
	'                              CvMat* dpdrot CV_DEFAULT(NULL), CvMat* dpdt CV_DEFAULT(NULL),
	'                              CvMat* dpdf CV_DEFAULT(NULL), CvMat* dpdc CV_DEFAULT(NULL),
	'                              CvMat* dpddist CV_DEFAULT(NULL) );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byref dpddist as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byref dpdc as CvMat,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byref dpdf as CvMat,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byref dpdt as CvMat,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byref dpdrot as CvMat,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref image_points as CvMat,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byref object_points as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvProjectPoints2(byval object_points as intptr,byval rotation_vector as intptr,byval translation_vector as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval image_points as intptr,byval dpdrot as intptr,byval dpdt as intptr,byval dpdf as intptr,byval dpdc as intptr,byval dpddist as intptr)
	end sub

	'/* finds extrinsic camera parameters from
	'   a few known corresponding point pairs and intrinsic parameters */
	'CVAPI(void) cvFindExtrinsicCameraParams2( const CvMat* object_points,
	'                                          const CvMat* image_points,
	'                                          const CvMat* intrinsic_matrix,
	'                                          const CvMat* distortion_coeffs,
	'                                          CvMat* rotation_vector,
	'                                          CvMat* translation_vector );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byref object_points as CvMat,byref image_points as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byval object_points as intptr,byref image_points as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byref object_points as CvMat,byval image_points as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byval object_points as intptr,byval image_points as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byref object_points as CvMat,byref image_points as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byval object_points as intptr,byref image_points as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byref object_points as CvMat,byval image_points as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byval object_points as intptr,byval image_points as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref rotation_vector as CvMat,byref translation_vector as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byref object_points as CvMat,byref image_points as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byval object_points as intptr,byref image_points as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byref object_points as CvMat,byval image_points as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byval object_points as intptr,byval image_points as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byref object_points as CvMat,byref image_points as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byval object_points as intptr,byref image_points as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byref object_points as CvMat,byval image_points as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byval object_points as intptr,byval image_points as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref rotation_vector as CvMat,byref translation_vector as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byref object_points as CvMat,byref image_points as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byval object_points as intptr,byref image_points as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byref object_points as CvMat,byval image_points as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byval object_points as intptr,byval image_points as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byref object_points as CvMat,byref image_points as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byval object_points as intptr,byref image_points as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byref object_points as CvMat,byval image_points as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byval object_points as intptr,byval image_points as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval rotation_vector as intptr,byref translation_vector as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byref object_points as CvMat,byref image_points as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byval object_points as intptr,byref image_points as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byref object_points as CvMat,byval image_points as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byval object_points as intptr,byval image_points as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byref object_points as CvMat,byref image_points as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byval object_points as intptr,byref image_points as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byref object_points as CvMat,byval image_points as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byval object_points as intptr,byval image_points as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval rotation_vector as intptr,byref translation_vector as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byref object_points as CvMat,byref image_points as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byval object_points as intptr,byref image_points as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byref object_points as CvMat,byval image_points as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byval object_points as intptr,byval image_points as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byref object_points as CvMat,byref image_points as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byval object_points as intptr,byref image_points as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byref object_points as CvMat,byval image_points as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byval object_points as intptr,byval image_points as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref rotation_vector as CvMat,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byref object_points as CvMat,byref image_points as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byval object_points as intptr,byref image_points as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byref object_points as CvMat,byval image_points as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byval object_points as intptr,byval image_points as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byref object_points as CvMat,byref image_points as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byval object_points as intptr,byref image_points as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byref object_points as CvMat,byval image_points as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byval object_points as intptr,byval image_points as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref rotation_vector as CvMat,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byref object_points as CvMat,byref image_points as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byval object_points as intptr,byref image_points as CvMat,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byref object_points as CvMat,byval image_points as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byval object_points as intptr,byval image_points as intptr,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byref object_points as CvMat,byref image_points as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byval object_points as intptr,byref image_points as CvMat,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byref object_points as CvMat,byval image_points as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byval object_points as intptr,byval image_points as intptr,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval rotation_vector as intptr,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byref object_points as CvMat,byref image_points as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval rotation_vector as intptr,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byval object_points as intptr,byref image_points as CvMat,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval rotation_vector as intptr,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byref object_points as CvMat,byval image_points as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval rotation_vector as intptr,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byval object_points as intptr,byval image_points as intptr,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval rotation_vector as intptr,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byref object_points as CvMat,byref image_points as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval rotation_vector as intptr,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byval object_points as intptr,byref image_points as CvMat,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval rotation_vector as intptr,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byref object_points as CvMat,byval image_points as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval rotation_vector as intptr,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvFindExtrinsicCameraParams2(byval object_points as intptr,byval image_points as intptr,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval rotation_vector as intptr,byval translation_vector as intptr)
	end sub

	'#define CV_CALIB_USE_INTRINSIC_GUESS  1
	public const  CV_CALIB_USE_INTRINSIC_GUESS as integer =  1
	'#define CV_CALIB_FIX_ASPECT_RATIO     2
	public const  CV_CALIB_FIX_ASPECT_RATIO as integer =  2
	'#define CV_CALIB_FIX_PRINCIPAL_POINT  4
	public const  CV_CALIB_FIX_PRINCIPAL_POINT as integer =  4
	'#define CV_CALIB_ZERO_TANGENT_DIST    8
	public const  CV_CALIB_ZERO_TANGENT_DIST as integer =  8

	'/* finds intrinsic and extrinsic camera parameters
	'   from a few views of known calibration pattern */
	'CVAPI(void) cvCalibrateCamera2( const CvMat* object_points,
	'                                const CvMat* image_points,
	'                                const CvMat* point_counts,
	'                                CvSize image_size,
	'                                CvMat* intrinsic_matrix,
	'                                CvMat* distortion_coeffs,
	'                                CvMat* rotation_vectors CV_DEFAULT(NULL),
	'                                CvMat* translation_vectors CV_DEFAULT(NULL),
	'                                int flags CV_DEFAULT(0) );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byref image_points as CvMat,byref point_counts as CvMat,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref rotation_vectors as CvMat,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byref image_points as CvMat,byref point_counts as CvMat,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref rotation_vectors as CvMat,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byval image_points as intptr,byref point_counts as CvMat,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref rotation_vectors as CvMat,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byval image_points as intptr,byref point_counts as CvMat,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref rotation_vectors as CvMat,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byref image_points as CvMat,byval point_counts as intptr,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref rotation_vectors as CvMat,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byref image_points as CvMat,byval point_counts as intptr,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref rotation_vectors as CvMat,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byval image_points as intptr,byval point_counts as intptr,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref rotation_vectors as CvMat,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byval image_points as intptr,byval point_counts as intptr,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref rotation_vectors as CvMat,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byref image_points as CvMat,byref point_counts as CvMat,byval image_size as CvSize,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref rotation_vectors as CvMat,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byref image_points as CvMat,byref point_counts as CvMat,byval image_size as CvSize,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref rotation_vectors as CvMat,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byval image_points as intptr,byref point_counts as CvMat,byval image_size as CvSize,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref rotation_vectors as CvMat,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byval image_points as intptr,byref point_counts as CvMat,byval image_size as CvSize,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref rotation_vectors as CvMat,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byref image_points as CvMat,byval point_counts as intptr,byval image_size as CvSize,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref rotation_vectors as CvMat,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byref image_points as CvMat,byval point_counts as intptr,byval image_size as CvSize,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref rotation_vectors as CvMat,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byval image_points as intptr,byval point_counts as intptr,byval image_size as CvSize,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref rotation_vectors as CvMat,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byval image_points as intptr,byval point_counts as intptr,byval image_size as CvSize,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref rotation_vectors as CvMat,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byref image_points as CvMat,byref point_counts as CvMat,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref rotation_vectors as CvMat,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byref image_points as CvMat,byref point_counts as CvMat,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref rotation_vectors as CvMat,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byval image_points as intptr,byref point_counts as CvMat,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref rotation_vectors as CvMat,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byval image_points as intptr,byref point_counts as CvMat,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref rotation_vectors as CvMat,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byref image_points as CvMat,byval point_counts as intptr,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref rotation_vectors as CvMat,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byref image_points as CvMat,byval point_counts as intptr,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref rotation_vectors as CvMat,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byval image_points as intptr,byval point_counts as intptr,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref rotation_vectors as CvMat,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byval image_points as intptr,byval point_counts as intptr,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref rotation_vectors as CvMat,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byref image_points as CvMat,byref point_counts as CvMat,byval image_size as CvSize,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref rotation_vectors as CvMat,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byref image_points as CvMat,byref point_counts as CvMat,byval image_size as CvSize,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref rotation_vectors as CvMat,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byval image_points as intptr,byref point_counts as CvMat,byval image_size as CvSize,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref rotation_vectors as CvMat,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byval image_points as intptr,byref point_counts as CvMat,byval image_size as CvSize,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref rotation_vectors as CvMat,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byref image_points as CvMat,byval point_counts as intptr,byval image_size as CvSize,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref rotation_vectors as CvMat,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byref image_points as CvMat,byval point_counts as intptr,byval image_size as CvSize,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref rotation_vectors as CvMat,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byval image_points as intptr,byval point_counts as intptr,byval image_size as CvSize,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref rotation_vectors as CvMat,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byval image_points as intptr,byval point_counts as intptr,byval image_size as CvSize,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref rotation_vectors as CvMat,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byref image_points as CvMat,byref point_counts as CvMat,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval rotation_vectors as intptr,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byref image_points as CvMat,byref point_counts as CvMat,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval rotation_vectors as intptr,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byval image_points as intptr,byref point_counts as CvMat,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval rotation_vectors as intptr,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byval image_points as intptr,byref point_counts as CvMat,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval rotation_vectors as intptr,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byref image_points as CvMat,byval point_counts as intptr,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval rotation_vectors as intptr,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byref image_points as CvMat,byval point_counts as intptr,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval rotation_vectors as intptr,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byval image_points as intptr,byval point_counts as intptr,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval rotation_vectors as intptr,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byval image_points as intptr,byval point_counts as intptr,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval rotation_vectors as intptr,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byref image_points as CvMat,byref point_counts as CvMat,byval image_size as CvSize,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval rotation_vectors as intptr,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byref image_points as CvMat,byref point_counts as CvMat,byval image_size as CvSize,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval rotation_vectors as intptr,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byval image_points as intptr,byref point_counts as CvMat,byval image_size as CvSize,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval rotation_vectors as intptr,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byval image_points as intptr,byref point_counts as CvMat,byval image_size as CvSize,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval rotation_vectors as intptr,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byref image_points as CvMat,byval point_counts as intptr,byval image_size as CvSize,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval rotation_vectors as intptr,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byref image_points as CvMat,byval point_counts as intptr,byval image_size as CvSize,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval rotation_vectors as intptr,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byval image_points as intptr,byval point_counts as intptr,byval image_size as CvSize,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval rotation_vectors as intptr,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byval image_points as intptr,byval point_counts as intptr,byval image_size as CvSize,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval rotation_vectors as intptr,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byref image_points as CvMat,byref point_counts as CvMat,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval rotation_vectors as intptr,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byref image_points as CvMat,byref point_counts as CvMat,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval rotation_vectors as intptr,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byval image_points as intptr,byref point_counts as CvMat,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval rotation_vectors as intptr,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byval image_points as intptr,byref point_counts as CvMat,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval rotation_vectors as intptr,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byref image_points as CvMat,byval point_counts as intptr,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval rotation_vectors as intptr,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byref image_points as CvMat,byval point_counts as intptr,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval rotation_vectors as intptr,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byval image_points as intptr,byval point_counts as intptr,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval rotation_vectors as intptr,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byval image_points as intptr,byval point_counts as intptr,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval rotation_vectors as intptr,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byref image_points as CvMat,byref point_counts as CvMat,byval image_size as CvSize,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval rotation_vectors as intptr,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byref image_points as CvMat,byref point_counts as CvMat,byval image_size as CvSize,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval rotation_vectors as intptr,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byval image_points as intptr,byref point_counts as CvMat,byval image_size as CvSize,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval rotation_vectors as intptr,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byval image_points as intptr,byref point_counts as CvMat,byval image_size as CvSize,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval rotation_vectors as intptr,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byref image_points as CvMat,byval point_counts as intptr,byval image_size as CvSize,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval rotation_vectors as intptr,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byref image_points as CvMat,byval point_counts as intptr,byval image_size as CvSize,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval rotation_vectors as intptr,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byval image_points as intptr,byval point_counts as intptr,byval image_size as CvSize,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval rotation_vectors as intptr,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byval image_points as intptr,byval point_counts as intptr,byval image_size as CvSize,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval rotation_vectors as intptr,byref translation_vectors as CvMat,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byref image_points as CvMat,byref point_counts as CvMat,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref rotation_vectors as CvMat,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byref image_points as CvMat,byref point_counts as CvMat,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref rotation_vectors as CvMat,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byval image_points as intptr,byref point_counts as CvMat,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref rotation_vectors as CvMat,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byval image_points as intptr,byref point_counts as CvMat,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref rotation_vectors as CvMat,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byref image_points as CvMat,byval point_counts as intptr,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref rotation_vectors as CvMat,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byref image_points as CvMat,byval point_counts as intptr,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref rotation_vectors as CvMat,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byval image_points as intptr,byval point_counts as intptr,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref rotation_vectors as CvMat,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byval image_points as intptr,byval point_counts as intptr,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byref rotation_vectors as CvMat,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byref image_points as CvMat,byref point_counts as CvMat,byval image_size as CvSize,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref rotation_vectors as CvMat,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byref image_points as CvMat,byref point_counts as CvMat,byval image_size as CvSize,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref rotation_vectors as CvMat,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byval image_points as intptr,byref point_counts as CvMat,byval image_size as CvSize,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref rotation_vectors as CvMat,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byval image_points as intptr,byref point_counts as CvMat,byval image_size as CvSize,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref rotation_vectors as CvMat,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byref image_points as CvMat,byval point_counts as intptr,byval image_size as CvSize,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref rotation_vectors as CvMat,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byref image_points as CvMat,byval point_counts as intptr,byval image_size as CvSize,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref rotation_vectors as CvMat,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byval image_points as intptr,byval point_counts as intptr,byval image_size as CvSize,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref rotation_vectors as CvMat,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byval image_points as intptr,byval point_counts as intptr,byval image_size as CvSize,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byref rotation_vectors as CvMat,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byref image_points as CvMat,byref point_counts as CvMat,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref rotation_vectors as CvMat,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byref image_points as CvMat,byref point_counts as CvMat,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref rotation_vectors as CvMat,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byval image_points as intptr,byref point_counts as CvMat,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref rotation_vectors as CvMat,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byval image_points as intptr,byref point_counts as CvMat,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref rotation_vectors as CvMat,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byref image_points as CvMat,byval point_counts as intptr,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref rotation_vectors as CvMat,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byref image_points as CvMat,byval point_counts as intptr,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref rotation_vectors as CvMat,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byval image_points as intptr,byval point_counts as intptr,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref rotation_vectors as CvMat,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byval image_points as intptr,byval point_counts as intptr,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byref rotation_vectors as CvMat,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byref image_points as CvMat,byref point_counts as CvMat,byval image_size as CvSize,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref rotation_vectors as CvMat,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byref image_points as CvMat,byref point_counts as CvMat,byval image_size as CvSize,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref rotation_vectors as CvMat,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byval image_points as intptr,byref point_counts as CvMat,byval image_size as CvSize,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref rotation_vectors as CvMat,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byval image_points as intptr,byref point_counts as CvMat,byval image_size as CvSize,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref rotation_vectors as CvMat,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byref image_points as CvMat,byval point_counts as intptr,byval image_size as CvSize,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref rotation_vectors as CvMat,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byref image_points as CvMat,byval point_counts as intptr,byval image_size as CvSize,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref rotation_vectors as CvMat,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byval image_points as intptr,byval point_counts as intptr,byval image_size as CvSize,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref rotation_vectors as CvMat,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byval image_points as intptr,byval point_counts as intptr,byval image_size as CvSize,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byref rotation_vectors as CvMat,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byref image_points as CvMat,byref point_counts as CvMat,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval rotation_vectors as intptr,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byref image_points as CvMat,byref point_counts as CvMat,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval rotation_vectors as intptr,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byval image_points as intptr,byref point_counts as CvMat,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval rotation_vectors as intptr,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byval image_points as intptr,byref point_counts as CvMat,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval rotation_vectors as intptr,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byref image_points as CvMat,byval point_counts as intptr,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval rotation_vectors as intptr,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byref image_points as CvMat,byval point_counts as intptr,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval rotation_vectors as intptr,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byval image_points as intptr,byval point_counts as intptr,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval rotation_vectors as intptr,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byval image_points as intptr,byval point_counts as intptr,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byref distortion_coeffs as CvMat,byval rotation_vectors as intptr,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byref image_points as CvMat,byref point_counts as CvMat,byval image_size as CvSize,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval rotation_vectors as intptr,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byref image_points as CvMat,byref point_counts as CvMat,byval image_size as CvSize,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval rotation_vectors as intptr,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byval image_points as intptr,byref point_counts as CvMat,byval image_size as CvSize,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval rotation_vectors as intptr,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byval image_points as intptr,byref point_counts as CvMat,byval image_size as CvSize,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval rotation_vectors as intptr,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byref image_points as CvMat,byval point_counts as intptr,byval image_size as CvSize,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval rotation_vectors as intptr,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byref image_points as CvMat,byval point_counts as intptr,byval image_size as CvSize,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval rotation_vectors as intptr,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byval image_points as intptr,byval point_counts as intptr,byval image_size as CvSize,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval rotation_vectors as intptr,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byval image_points as intptr,byval point_counts as intptr,byval image_size as CvSize,byval intrinsic_matrix as intptr,byref distortion_coeffs as CvMat,byval rotation_vectors as intptr,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byref image_points as CvMat,byref point_counts as CvMat,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval rotation_vectors as intptr,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byref image_points as CvMat,byref point_counts as CvMat,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval rotation_vectors as intptr,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byval image_points as intptr,byref point_counts as CvMat,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval rotation_vectors as intptr,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byval image_points as intptr,byref point_counts as CvMat,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval rotation_vectors as intptr,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byref image_points as CvMat,byval point_counts as intptr,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval rotation_vectors as intptr,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byref image_points as CvMat,byval point_counts as intptr,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval rotation_vectors as intptr,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byval image_points as intptr,byval point_counts as intptr,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval rotation_vectors as intptr,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byval image_points as intptr,byval point_counts as intptr,byval image_size as CvSize,byref intrinsic_matrix as CvMat,byval distortion_coeffs as intptr,byval rotation_vectors as intptr,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byref image_points as CvMat,byref point_counts as CvMat,byval image_size as CvSize,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval rotation_vectors as intptr,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byref image_points as CvMat,byref point_counts as CvMat,byval image_size as CvSize,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval rotation_vectors as intptr,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byval image_points as intptr,byref point_counts as CvMat,byval image_size as CvSize,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval rotation_vectors as intptr,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byval image_points as intptr,byref point_counts as CvMat,byval image_size as CvSize,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval rotation_vectors as intptr,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byref image_points as CvMat,byval point_counts as intptr,byval image_size as CvSize,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval rotation_vectors as intptr,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byref image_points as CvMat,byval point_counts as intptr,byval image_size as CvSize,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval rotation_vectors as intptr,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byref object_points as CvMat,byval image_points as intptr,byval point_counts as intptr,byval image_size as CvSize,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval rotation_vectors as intptr,byval translation_vectors as intptr,byval flags as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvCalibrateCamera2(byval object_points as intptr,byval image_points as intptr,byval point_counts as intptr,byval image_size as CvSize,byval intrinsic_matrix as intptr,byval distortion_coeffs as intptr,byval rotation_vectors as intptr,byval translation_vectors as intptr,byval flags as integer)
	end sub

	'#define CV_CALIB_CB_ADAPTIVE_THRESH  1
	public const  CV_CALIB_CB_ADAPTIVE_THRESH as integer =  1
	'#define CV_CALIB_CB_NORMALIZE_IMAGE  2
	public const  CV_CALIB_CB_NORMALIZE_IMAGE as integer =  2
	'#define CV_CALIB_CB_FILTER_QUADS     4 
	public const  CV_CALIB_CB_FILTER_QUADS as integer =  4

	'/* Detects corners on a chessboard calibration pattern */
	'CVAPI(int) cvFindChessboardCorners( const void* image, CvSize pattern_size,
	'                                    CvPoint2D32f* corners,
	'                                    int* corner_count CV_DEFAULT(NULL),
	'                                    int flags CV_DEFAULT(CV_CALIB_CB_ADAPTIVE_THRESH) );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvFindChessboardCorners(byval image as intptr,byval pattern_size as CvSize,byref corners as CvPoint2D32f,byval corner_count as integer(),byval flags as integer) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvFindChessboardCorners(byval image as intptr,byval pattern_size as CvSize,byval corners as intptr,byval corner_count as integer(),byval flags as integer) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvFindChessboardCorners(byval image as intptr,byval pattern_size as CvSize,byref corners as CvPoint2D32f,byref corner_count as integer,byval flags as integer) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvFindChessboardCorners(byval image as intptr,byval pattern_size as CvSize,byval corners as intptr,byref corner_count as integer,byval flags as integer) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvFindChessboardCorners(byval image as intptr,byval pattern_size as CvSize,byref corners as CvPoint2D32f,byval corner_count as intptr,byval flags as integer) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvFindChessboardCorners(byval image as intptr,byval pattern_size as CvSize,byval corners as intptr,byval corner_count as intptr,byval flags as integer) as integer
	end function

	'/* Draws individual chessboard corners or the whole chessboard detected */
	'CVAPI(void) cvDrawChessboardCorners( CvArr* image, CvSize pattern_size,
	'                                     CvPoint2D32f* corners,
	'                                     int count, int pattern_was_found );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvDrawChessboardCorners(byval image as intptr,byval pattern_size as CvSize,byref corners as CvPoint2D32f,byval count as integer,byval pattern_was_found as integer)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvDrawChessboardCorners(byval image as intptr,byval pattern_size as CvSize,byval corners as intptr,byval count as integer,byval pattern_was_found as integer)
	end sub

	'typedef struct CvPOSITObject CvPOSITObject;
	'ToDo : Typedef

	'/* Allocates and initializes CvPOSITObject structure before doing cvPOSIT */
	'CVAPI(CvPOSITObject*)  cvCreatePOSITObject( CvPoint3D32f* points, int point_count );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvCreatePOSITObject(byref points as CvPoint3D32f,byval point_count as integer) as IntPtr
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvCreatePOSITObject(byval points as intptr,byval point_count as integer) as IntPtr
	end function


	'/* Runs POSIT (POSe from ITeration) algorithm for determining 3d position of
	'   an object given its model and projection in a weak-perspective case */
	'CVAPI(void)  cvPOSIT(  CvPOSITObject* posit_object, CvPoint2D32f* image_points,
	'                       double focal_length, CvTermCriteria criteria,
	'                       CvMatr32f rotation_matrix, CvVect32f translation_vector);
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvPOSIT(byval posit_object as intptr,byref image_points as CvPoint2D32f,byval focal_length as double,byval criteria as CvTermCriteria,byval rotation_matrix() as single,byval translation_vector() as single)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvPOSIT(byval posit_object as intptr,byval image_points as intptr,byval focal_length as double,byval criteria as CvTermCriteria,byval rotation_matrix() as single,byval translation_vector() as single)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvPOSIT(byval posit_object as intptr,byref image_points as CvPoint2D32f,byval focal_length as double,byval criteria as CvTermCriteria,byval rotation_matrix as intptr,byval translation_vector() as single)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvPOSIT(byval posit_object as intptr,byval image_points as intptr,byval focal_length as double,byval criteria as CvTermCriteria,byval rotation_matrix as intptr,byval translation_vector() as single)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvPOSIT(byval posit_object as intptr,byref image_points as CvPoint2D32f,byval focal_length as double,byval criteria as CvTermCriteria,byval rotation_matrix() as single,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvPOSIT(byval posit_object as intptr,byval image_points as intptr,byval focal_length as double,byval criteria as CvTermCriteria,byval rotation_matrix() as single,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvPOSIT(byval posit_object as intptr,byref image_points as CvPoint2D32f,byval focal_length as double,byval criteria as CvTermCriteria,byval rotation_matrix as intptr,byval translation_vector as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvPOSIT(byval posit_object as intptr,byval image_points as intptr,byval focal_length as double,byval criteria as CvTermCriteria,byval rotation_matrix as intptr,byval translation_vector as intptr)
	end sub

	'/* Releases CvPOSITObject structure */
	'CVAPI(void)  cvReleasePOSITObject( CvPOSITObject**  posit_object );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvReleasePOSITObject(byref posit_object as intptr)
	end sub


	'/****************************************************************************************\
	'*                                 Epipolar Geometry                                      *
	'\****************************************************************************************/

	'CVAPI(void) cvConvertPointsHomogenious( const CvMat* src, CvMat* dst );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvConvertPointsHomogenious(byref src as CvMat,byref dst as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvConvertPointsHomogenious(byval src as intptr,byref dst as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvConvertPointsHomogenious(byref src as CvMat,byval dst as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvConvertPointsHomogenious(byval src as intptr,byval dst as intptr)
	end sub

	'/* Calculates fundamental matrix given a set of corresponding points */
	'#define CV_FM_7POINT 1
	public const  CV_FM_7POINT as integer =  1
	'#define CV_FM_8POINT 2
	public const  CV_FM_8POINT as integer =  2
	'#define CV_FM_LMEDS_ONLY  4
	public const  CV_FM_LMEDS_ONLY as integer =  4
	'#define CV_FM_RANSAC_ONLY 8
	public const  CV_FM_RANSAC_ONLY as integer =  8
	'#define CV_FM_LMEDS (CV_FM_LMEDS_ONLY + CV_FM_8POINT)
	public const  CV_FM_LMEDS as integer =  (CV_FM_LMEDS_ONLY + CV_FM_8POINT)
	'#define CV_FM_RANSAC (CV_FM_RANSAC_ONLY + CV_FM_8POINT)
	public const  CV_FM_RANSAC as integer =  (CV_FM_RANSAC_ONLY + CV_FM_8POINT)
	'CVAPI(int) cvFindFundamentalMat( const CvMat* points1, const CvMat* points2,
	'                                 CvMat* fundamental_matrix,
	'                                 int method CV_DEFAULT(CV_FM_RANSAC),
	'                                 double param1 CV_DEFAULT(1.), double param2 CV_DEFAULT(0.99),
	'                                 CvMat* status CV_DEFAULT(NULL) );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvFindFundamentalMat(byref points1 as CvMat,byref points2 as CvMat,byref fundamental_matrix as CvMat,byval method as integer,byval param1 as double,byval param2 as double,byref status as CvMat) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvFindFundamentalMat(byval points1 as intptr,byref points2 as CvMat,byref fundamental_matrix as CvMat,byval method as integer,byval param1 as double,byval param2 as double,byref status as CvMat) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvFindFundamentalMat(byref points1 as CvMat,byval points2 as intptr,byref fundamental_matrix as CvMat,byval method as integer,byval param1 as double,byval param2 as double,byref status as CvMat) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvFindFundamentalMat(byval points1 as intptr,byval points2 as intptr,byref fundamental_matrix as CvMat,byval method as integer,byval param1 as double,byval param2 as double,byref status as CvMat) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvFindFundamentalMat(byref points1 as CvMat,byref points2 as CvMat,byval fundamental_matrix as intptr,byval method as integer,byval param1 as double,byval param2 as double,byref status as CvMat) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvFindFundamentalMat(byval points1 as intptr,byref points2 as CvMat,byval fundamental_matrix as intptr,byval method as integer,byval param1 as double,byval param2 as double,byref status as CvMat) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvFindFundamentalMat(byref points1 as CvMat,byval points2 as intptr,byval fundamental_matrix as intptr,byval method as integer,byval param1 as double,byval param2 as double,byref status as CvMat) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvFindFundamentalMat(byval points1 as intptr,byval points2 as intptr,byval fundamental_matrix as intptr,byval method as integer,byval param1 as double,byval param2 as double,byref status as CvMat) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvFindFundamentalMat(byref points1 as CvMat,byref points2 as CvMat,byref fundamental_matrix as CvMat,byval method as integer,byval param1 as double,byval param2 as double,byval status as intptr) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvFindFundamentalMat(byval points1 as intptr,byref points2 as CvMat,byref fundamental_matrix as CvMat,byval method as integer,byval param1 as double,byval param2 as double,byval status as intptr) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvFindFundamentalMat(byref points1 as CvMat,byval points2 as intptr,byref fundamental_matrix as CvMat,byval method as integer,byval param1 as double,byval param2 as double,byval status as intptr) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvFindFundamentalMat(byval points1 as intptr,byval points2 as intptr,byref fundamental_matrix as CvMat,byval method as integer,byval param1 as double,byval param2 as double,byval status as intptr) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvFindFundamentalMat(byref points1 as CvMat,byref points2 as CvMat,byval fundamental_matrix as intptr,byval method as integer,byval param1 as double,byval param2 as double,byval status as intptr) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvFindFundamentalMat(byval points1 as intptr,byref points2 as CvMat,byval fundamental_matrix as intptr,byval method as integer,byval param1 as double,byval param2 as double,byval status as intptr) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvFindFundamentalMat(byref points1 as CvMat,byval points2 as intptr,byval fundamental_matrix as intptr,byval method as integer,byval param1 as double,byval param2 as double,byval status as intptr) as integer
	end function
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public function cvFindFundamentalMat(byval points1 as intptr,byval points2 as intptr,byval fundamental_matrix as intptr,byval method as integer,byval param1 as double,byval param2 as double,byval status as intptr) as integer
	end function

	'/* For each input point on one of images
	'   computes parameters of the corresponding
	'   epipolar line on the other image */
	'CVAPI(void) cvComputeCorrespondEpilines( const CvMat* points,
	'                                         int which_image,
	'                                         const CvMat* fundamental_matrix,
	'                                         CvMat* correspondent_lines );
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvComputeCorrespondEpilines(byref points as CvMat,byval which_image as integer,byref fundamental_matrix as CvMat,byref correspondent_lines as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvComputeCorrespondEpilines(byval points as intptr,byval which_image as integer,byref fundamental_matrix as CvMat,byref correspondent_lines as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvComputeCorrespondEpilines(byref points as CvMat,byval which_image as integer,byval fundamental_matrix as intptr,byref correspondent_lines as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvComputeCorrespondEpilines(byval points as intptr,byval which_image as integer,byval fundamental_matrix as intptr,byref correspondent_lines as CvMat)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvComputeCorrespondEpilines(byref points as CvMat,byval which_image as integer,byref fundamental_matrix as CvMat,byval correspondent_lines as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvComputeCorrespondEpilines(byval points as intptr,byval which_image as integer,byref fundamental_matrix as CvMat,byval correspondent_lines as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvComputeCorrespondEpilines(byref points as CvMat,byval which_image as integer,byval fundamental_matrix as intptr,byval correspondent_lines as intptr)
	end sub
	<DllImport(OpenCVInformation.Cv, CallingConvention:=CallingConvention.Cdecl, CharSet:=CharSet.Ansi)> _
	public sub cvComputeCorrespondEpilines(byval points as intptr,byval which_image as integer,byval fundamental_matrix as intptr,byval correspondent_lines as intptr)
	end sub


End Module
